@@ -36,6 +36,7 @@
 
 #define KZ_ACTIONS_POPUP_LANGUAGE_KEY "KzActionsPopup::Language"
 #define KZ_ACTIONS_POPUP_TAB_KEY "KzActionsPopup::Tab"
+#define KZ_ACTIONS_POPUP_COPY_IN_USER_FORMAT_KEY "KzActionsPopup::CopyInUserFormat"
 
 typedef enum {
 	LOCATION_LINK,
@@ -170,7 +171,7 @@ act_popup_save_link (GtkAction *action, KzWindow *kz)
 	g_return_if_fail(event);
 
 	uri = event->cinfo.link;
-	kz_actions_download_open_save_dialog(uri, FALSE);
+	kz_actions_download_open_save_dialog(GTK_WINDOW(kz), uri, FALSE);
 }
 
 static void
@@ -185,7 +186,7 @@ act_popup_save_image (GtkAction *action, KzWindow *kz)
 	g_return_if_fail(event);
 
 	uri = event->cinfo.img;
-	kz_actions_download_open_save_dialog(uri, FALSE);
+	kz_actions_download_open_save_dialog(GTK_WINDOW(kz), uri, FALSE);
 }
 
 static void
@@ -213,7 +214,7 @@ cb_embed_changed (KzEmbed *embed, EditorInfo *einfo)
 	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(einfo);
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(embed),
+	g_signal_handlers_disconnect_by_func(embed,
 			 		     G_CALLBACK(cb_embed_changed),
 					     einfo);
 	if (!einfo) return;
@@ -242,7 +243,7 @@ cb_editor_exit (GPid pid, gint status, gpointer data)
 	einfo = (EditorInfo*)data;
 	if (einfo->kzembed)
 	{
-		g_signal_handlers_disconnect_by_func(G_OBJECT(einfo->kzembed),
+		g_signal_handlers_disconnect_by_func(einfo->kzembed,
 			 		     G_CALLBACK(cb_embed_changed),
 					     einfo);
 	}
@@ -330,9 +331,9 @@ act_popup_launch_editor (GtkAction *action, KzWindow *kz)
 	}
 	
 	/* */
-	g_signal_connect(G_OBJECT(widget), "kz-net-start",
+	g_signal_connect(widget, "kz-net-start",
 			 G_CALLBACK(cb_embed_changed), einfo);
-	g_signal_connect(G_OBJECT(widget), "destroy",
+	g_signal_connect(widget, "destroy",
 			 G_CALLBACK(cb_embed_changed), einfo);
 	/* launch editor */
 	g_shell_parse_argv(command,
@@ -366,6 +367,112 @@ cb_popup_menu_hide (void)
 	gtk_main_quit();
 }
 
+static void
+cb_copy_in_user_format_menuitem_activate (GtkWidget *menuitem, KzWindow *kz)
+{
+	GtkWidget *widget;
+	gint idx = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(menuitem),
+						     KZ_ACTIONS_POPUP_COPY_IN_USER_FORMAT_KEY));
+	gchar conf_key[] = "copy_document_format99";
+	gchar *format;
+	gchar *text;
+	gchar *str;
+	gint i;
+	gint counts = 0;
+
+	g_return_if_fail(0 < idx && idx < 100);
+	g_return_if_fail(KZ_IS_WINDOW (kz));
+
+	widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	 if (!KZ_IS_EMBED(widget)) return;
+
+	text = kz_embed_get_selection_string(KZ_EMBED(widget));
+	if (!text) text = g_strdup("");
+
+	g_snprintf(conf_key, sizeof(conf_key), "copy_document_format%d", idx);
+	format = KZ_CONF_GET_STR("Global" , conf_key);
+	g_return_if_fail(format);
+
+	for(i = 0; format[i] != '\0'; i++)
+		if(format[i] == '%') counts++;
+	counts++;
+
+	if(counts != 1)
+	{
+		gchar **temp = g_alloca(sizeof(gchar*) * (counts + 1));
+		gchar **splited = g_strsplit(format , "%" , counts);
+		gint st = 0;
+
+		for(i = 0; i < counts-1; i++)
+		{
+			if(st == 0)
+			{
+				/* first state */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if (st == 2)
+			{
+				/* after %t% and so on */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if (splited[i][0] == '\0')
+			{
+				/* "%%" */
+				temp[i] = "%";
+				st = 0;
+			}
+			else if (splited[i][1] != '\0')
+			{
+				/* %text% */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if(splited[i][0] == 't')
+			{
+				/* %t% */
+				temp[i] = (gchar*)kz_embed_get_title(KZ_EMBED(widget));
+				st = 2;
+			}
+			else if(splited[i][0] == 'u')
+			{
+				/* %u% */
+				temp[i] = (gchar*)kz_embed_get_location(KZ_EMBED(widget));
+				st = 2;
+			}
+			else if(splited[i][0] == 's')
+			{
+				/* %s% */
+				temp[i] = text;
+				st = 2;
+			}
+			else
+			{
+				/* '%' + other char + '%' */
+				temp[i] = splited[i];
+				st = 1;
+			}
+		}
+		temp[counts-1] = splited[counts-1];
+		temp[counts] = NULL;
+
+		str = g_strjoinv(NULL , temp);
+		g_strfreev(splited);
+	}
+	else
+	{
+		str = g_strdup(format);
+	}
+
+	g_free(format);
+
+	gtkutil_copy_text(str);
+
+	if(str) g_free(str);
+	if(text) g_free(text);
+}
+
 static void
 cb_tablist_menuitem_activate (GtkWidget *menuitem, KzWindow *kz)
 {
@@ -402,13 +509,13 @@ act_popup_tab_list (GtkAction *action, KzWindow *kz)
 
 	kz_actions_popup_append_tablist_menuitem(kz, popup_menu);
 	
-	g_signal_connect(G_OBJECT(popup_menu), "hide",
+	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), kz);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
 		       NULL, NULL, 0, 0);
 	gtk_main();
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(popup_menu),
+	g_signal_handlers_disconnect_by_func(popup_menu,
 					     G_CALLBACK(cb_popup_menu_hide), kz);
 }
 
@@ -578,9 +685,9 @@ create_lang_menu_item (KzWindow *kz, KzXMLNode *node,
 		g_object_set_data(G_OBJECT(menuitem),
 				  KZ_ACTIONS_POPUP_LANGUAGE_KEY,
 				  (gpointer) encoding);
-		g_signal_connect(G_OBJECT(menuitem), "activate",
+		g_signal_connect(menuitem, "activate",
 				 G_CALLBACK(cb_encoding_menuitem_activate), kz);
-		g_signal_connect(G_OBJECT(menuitem), "destroy",
+		g_signal_connect(menuitem, "destroy",
 				 G_CALLBACK(cb_encoding_menuitem_destroy), encoding);
 
 		if (forced && current_encoding &&
@@ -601,6 +708,61 @@ create_lang_menu_item (KzWindow *kz, KzXMLNode *node,
 	return menuitem;
 }
 
+static void
+kz_actions_popup_append_copy_in_user_format_menuitem (KzWindow *kz,
+						      GtkMenuItem *copy_in_user_format_menu)
+{
+	GtkWidget *copy_in_user_format_submenu;
+	GtkWidget *menuitem;
+	gchar *title;
+	gchar conf_key[] = "copy_document_format_title99";
+	gint i;
+
+	if (!popup_menu_table)
+	{
+		popup_menu_table = g_hash_table_new(g_direct_hash,
+						    g_direct_equal);
+	}
+
+	copy_in_user_format_submenu = g_hash_table_lookup(popup_menu_table, copy_in_user_format_menu);
+	if (copy_in_user_format_submenu) return;
+
+	/* append copy in user format menuitem */
+	copy_in_user_format_submenu = gtk_menu_new();
+
+	for (i = 1; i < 100; i++)
+	{
+		g_snprintf(conf_key, sizeof(conf_key), "copy_document_format_title%d", i);
+		title = KZ_CONF_GET_STR("Global" , conf_key);
+		if(!title) break;
+
+		menuitem = gtk_menu_item_new_with_label(title);
+
+		g_object_set_data (G_OBJECT(menuitem),
+				   KZ_ACTIONS_POPUP_COPY_IN_USER_FORMAT_KEY,
+				   GINT_TO_POINTER(i));
+
+		g_signal_connect(menuitem, "activate",
+				 G_CALLBACK(cb_copy_in_user_format_menuitem_activate),
+				 kz);
+
+		gtk_menu_shell_append(GTK_MENU_SHELL(copy_in_user_format_submenu),
+				      menuitem);
+		gtk_widget_show(menuitem);
+
+		g_free(title);
+	}
+
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(copy_in_user_format_menu),
+				  copy_in_user_format_submenu);
+
+	/* reference */
+	g_hash_table_insert(popup_menu_table, copy_in_user_format_menu,
+			    copy_in_user_format_submenu);
+	g_signal_connect(copy_in_user_format_menu, "destroy",
+			 G_CALLBACK(cb_popup_destroy), NULL);
+}
+
 static void
 kz_actions_popup_append_encoding_menuitem (KzWindow *kz,
 					   GtkMenuItem *encoding_menu)
@@ -643,7 +805,7 @@ kz_actions_popup_append_encoding_menuitem (KzWindow *kz,
 	g_object_set_data(G_OBJECT(menuitem),
 			  KZ_ACTIONS_POPUP_LANGUAGE_KEY, "");
 
-	g_signal_connect(G_OBJECT(menuitem), "activate",
+	g_signal_connect(menuitem, "activate",
 			 G_CALLBACK(cb_encoding_menuitem_activate), kz);
 
 	gtk_menu_shell_append(GTK_MENU_SHELL(encoding_submenu), menuitem);
@@ -681,7 +843,7 @@ kz_actions_popup_append_encoding_menuitem (KzWindow *kz,
 
 	/* reference */
 	g_hash_table_insert(popup_menu_table, encoding_menu, encoding_submenu);
-	g_signal_connect(G_OBJECT(encoding_menu), "destroy",
+	g_signal_connect(encoding_menu, "destroy",
 			 G_CALLBACK(cb_popup_destroy), NULL);
 }
 
@@ -801,7 +963,7 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 
 			g_object_set_data (G_OBJECT(menuitem), KZ_ACTIONS_POPUP_TAB_KEY, kzembed);
 
-			g_signal_connect(G_OBJECT(menuitem), "activate",
+			g_signal_connect(menuitem, "activate",
 					 G_CALLBACK(cb_tablist_menuitem_activate), kz);
 			gtk_menu_shell_append(GTK_MENU_SHELL(tablist_submenu), menuitem);
 			gtk_widget_show(menuitem);
@@ -817,7 +979,7 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 		g_hash_table_insert(popup_menu_table,
 				    tablist_menu,
 				    tablist_submenu);
-		g_signal_connect(G_OBJECT(tablist_menu), "destroy",
+		g_signal_connect(tablist_menu, "destroy",
 				 G_CALLBACK(cb_popup_destroy), NULL);
 	}
 	g_object_unref(kzfav);
@@ -882,6 +1044,17 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 		gtkutil_append_im_menuitem(GTK_MENU_SHELL(popup_menu));
 	}
 
+        /* add copy in user format */
+	g_snprintf(extra_menu_path,
+		   sizeof(extra_menu_path), "%s/CopyInUserFormat", path);
+
+	extra_menu = GET_MENU(kz, extra_menu_path);
+	if(extra_menu)
+	{
+		kz_actions_popup_append_copy_in_user_format_menuitem
+			(kz, GTK_MENU_ITEM(extra_menu));
+	}
+
         /* add encoding menu */
 	g_snprintf(extra_menu_path,
 		   sizeof(extra_menu_path), "%s/EncodingMenu", path);
@@ -902,12 +1075,12 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 		kz_actions_popup_append_tablist_menuitem(kz, extra_menu);
 	}
 
-	g_signal_connect(G_OBJECT(popup_menu), "hide",
+	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), kz);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
 		       NULL, NULL, 0, time);
 	gtk_main();
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(popup_menu),
+	g_signal_handlers_disconnect_by_func(popup_menu,
 					     G_CALLBACK(cb_popup_menu_hide), kz);
 }
