@@ -30,16 +30,12 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
-#include "gtk24backports.h"
 #include "kz-window.h"
-#include "kz-langinfo.h"
 
 G_BEGIN_DECLS
 
 extern GtkActionEntry      kz_actions_popup[];
 extern const gint          kz_actions_popup_len;
-extern const LanguageInfo  languages[];
-extern const gint          n_languages;
 
 GtkActionGroup *kz_actions_popup_create_group (KzWindow      *kz,
 					       GtkAccelGroup *accel_group);
