@@ -29,6 +29,28 @@
 static GQuark kztab_quark = 0;
 
 
+static KzTabLabel *
+get_tab_object (KzWindow *kz)
+{
+	KzTabLabel *kztab;
+
+	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+
+	if (!kztab)
+	{
+		GtkWidget *label;
+		GtkWidget *kzembed;
+
+		kzembed = GTK_WIDGET(KZ_WINDOW_CURRENT_PAGE(kz));
+		label = gtk_notebook_get_tab_label(GTK_NOTEBOOK(kz->notebook),
+						   kzembed);
+		if (KZ_IS_TAB_LABEL(label))
+			kztab = KZ_TAB_LABEL(label);
+	}
+
+	return kztab;
+}
+
 static void
 act_tab_reload (GtkAction *action, KzWindow *kz)
 {
@@ -80,7 +102,6 @@ close_all_tab (GtkAction *action, KzWindow *kz, gint mode)
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
-
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 	notebook = GTK_NOTEBOOK(kztab->kz->notebook);
 
@@ -195,7 +216,7 @@ act_tab_copy_title_and_location (GtkAction *action, KzWindow *kz)
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+	kztab = get_tab_object(kz);
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	str = g_strdup_printf("<a href=\"%s\" title=\"%s\">%s</a>",
@@ -206,38 +227,123 @@ act_tab_copy_title_and_location (GtkAction *action, KzWindow *kz)
 	g_free(str);
 }
 
+static void
+act_tab_copy_in_user_format (GtkAction *action, KzWindow *kz)
+{
+	KzTabLabel *kztab;
+	gchar *format;
+	gchar **splited = NULL;
+	gint counts = 0;
+	gint i;
+	gchar *str = NULL;
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	kztab = get_tab_object(kz);
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+
+	format = KZ_CONF_GET_STR("Global" , "copy_tab_format1");
+	if(!format) return;
+
+	for(i = 0;format[i] != '\0';i++)
+		if(format[i] == '%') counts++;
+	counts++;
+	
+	if(counts != 1)
+	{
+		gchar **temp = g_new0(gchar*, counts + 1);
+		splited = g_strsplit(format , "%" , counts);
+
+		for (i = 0;i < counts;i++)
+		{
+			if (splited[i][0] == 't')
+				temp[i] = (gchar*)kz_embed_get_title(KZ_EMBED(kztab->kzembed));
+			else if(splited[i][0] == 'u')
+				temp[i] = (gchar*)kz_embed_get_location(KZ_EMBED(kztab->kzembed));
+			else
+				temp[i] = splited[i];
+		}
+		temp[counts] = NULL;
+
+		str = g_strjoinv(NULL , temp);
+		g_strfreev(splited);
+	}
+	else
+	{
+		str = g_strdup(format);
+	}
+
+	g_free(format);
+
+	gtkutil_copy_text(str);
+
+	if(str)	g_free(str);
+}
+
 static void
 act_tab_toggle_lock (GtkAction *action, KzWindow *kz)
 {
 	KzTabLabel *kztab;
+	gboolean active;
 
 	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+	kztab = get_tab_object(kz);
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
-	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action)))
-		kz_tab_label_set_lock(kztab, TRUE);
-	else
-		kz_tab_label_set_lock(kztab, FALSE);
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	kz_tab_label_set_lock(kztab, active);
 }
 
 static void
 act_tab_toggle_auto_refresh (GtkAction *action, KzWindow *kz)
 {
 	KzTabLabel *kztab;
+	gboolean active;
 
 	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+	kztab = get_tab_object(kz);
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
-	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action)))
-		kz_tab_label_set_auto_refresh(kztab, TRUE);
-	else
-		kz_tab_label_set_auto_refresh(kztab, FALSE);
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	kz_tab_label_set_auto_refresh(kztab, active);
+}
+
+static void
+act_tab_toggle_javascript (GtkAction *action, KzWindow *kz)
+{
+	KzTabLabel *kztab;
+	gboolean active;
+
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	kztab = get_tab_object(kz);
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+
+	kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), active);
+}
+
+static void
+act_tab_toggle_images (GtkAction *action, KzWindow *kz)
+{
+	KzTabLabel *kztab;
+	gboolean active;
+
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	kztab = get_tab_object(kz);
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+
+	kz_embed_set_allow_images(KZ_EMBED(kztab->kzembed), active);
 }
 
 static void
@@ -289,6 +395,9 @@ GtkActionEntry kz_actions_tab[] =
 	{"TabCopyTitleLocation",     NULL, N_("Cop_y Title&Location"),
 	 NULL, NULL, G_CALLBACK(act_tab_copy_title_and_location)},
 
+	{"TabCopyInUserFormat",     NULL, N_("Cop_y _In user format"),
+	 NULL, NULL, G_CALLBACK(act_tab_copy_in_user_format)},
+
 	{"TabCopy",     NULL, N_("Tab Co_py"),
 	 NULL, NULL, G_CALLBACK(act_tab_copy_tab)},
 };
@@ -298,8 +407,12 @@ GtkToggleActionEntry kz_toggle_actions_tab[] =
 {
 	{"TabToggleLock",     KZ_STOCK_ANCHOR, N_("Tab Loc_k"),
 	 NULL, NULL, G_CALLBACK(act_tab_toggle_lock), FALSE},
-	{"TabAutoRefresh",     KZ_STOCK_ANCHOR, N_("Refresh Tab _automatically"),
+	{"TabAutoRefresh",     NULL,           N_("Refresh Tab _automatically"),
 	 NULL, NULL, G_CALLBACK(act_tab_toggle_auto_refresh), FALSE},
+	{"TabToggleJavascript",NULL,           N_("Enable _javascript"),
+	 NULL, NULL, G_CALLBACK(act_tab_toggle_javascript),   FALSE},
+	{"TabToggleImages",NULL,               N_("Show _images"),
+	 NULL, NULL, G_CALLBACK(act_tab_toggle_images),   FALSE},
 };
 const gint kz_actions_tab_len = G_N_ELEMENTS(kz_actions_tab);
 const gint kz_toggle_actions_tab_len = G_N_ELEMENTS(kz_toggle_actions_tab);
@@ -352,7 +465,7 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	KzWindow *kz;
 	GtkAction *action;
 	gint pos, num;
-	gboolean lock, auto_refresh;
+	gboolean lock, auto_refresh, javascript, images;
 
 	g_return_if_fail(kztab);
 
@@ -390,6 +503,16 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	auto_refresh = kz_tab_label_get_auto_refresh(kztab);
 	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), auto_refresh);
 
+	action = gtk_action_group_get_action(kz->tabpop_actions,
+					     "TabToggleJavascript");
+	javascript = kz_embed_get_allow_javascript(KZ_EMBED(kztab->kzembed));
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), javascript);
+
+	action = gtk_action_group_get_action(kz->tabpop_actions,
+					     "TabToggleImages");
+	images = kz_embed_get_allow_images(KZ_EMBED(kztab->kzembed));
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), images);
+
 	action = gtk_action_group_get_action(kz->tabpop_actions,
 					     "TabClose");
 	g_object_set(action, "sensitive", !lock, NULL);
@@ -415,12 +538,12 @@ kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 
 	set_popup_menu_sensitive(kztab);
 
-	g_signal_connect(G_OBJECT(popup_menu), "hide",
+	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), NULL);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
 		       NULL, NULL, button, time);
 	gtk_main();
-	g_signal_handlers_disconnect_by_func(G_OBJECT(popup_menu),
+	g_signal_handlers_disconnect_by_func(popup_menu,
 					     G_CALLBACK(cb_popup_menu_hide),
 					     NULL);
 
