@@ -786,7 +786,6 @@ act_copy (GtkAction *action, KzWindow *kz)
         }
 }
 
-
 static void
 act_paste (GtkAction *action, KzWindow *kz)
 {
@@ -866,6 +865,107 @@ act_copy_url (GtkAction *action, KzWindow *kz)
 	gtkutil_copy_text(text);
 }
 
+static void
+act_copy_in_user_format(GtkAction *action, KzWindow *kz)
+{
+	GtkWidget *widget;
+	gchar *text;
+	gchar *format;
+	gchar **splited = NULL;
+	gint counts = 0;
+	gint i;
+	gchar *str = NULL;
+
+	g_return_if_fail(KZ_IS_WINDOW (kz));
+	
+	widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	 if (!KZ_IS_EMBED(widget)) return;
+
+	text = kz_embed_get_selection_string(KZ_EMBED(widget));
+	if (!text) text = g_strdup("");
+
+	format = KZ_CONF_GET_STR("Global" , "copy_document_format1");
+	if(!format) return;
+
+	for(i = 0;format[i] != '\0';i++)
+		if(format[i] == '%') counts++;
+	counts++;
+	
+	if(counts != 1)
+	{
+		gchar **temp = g_alloca(sizeof(gchar*) * (counts + 1));
+		splited = g_strsplit(format , "%" , counts);
+		gint st = 0;
+
+		for(i = 0; i < counts-1; i++)
+		{
+			if(st == 0)
+			{
+				/* first state */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if (st == 2)
+			{
+				/* after %t% and so on */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if (splited[i][0] == '\0')
+			{
+				/* "%%" */
+				temp[i] = "%";
+				st = 0;
+			}
+			else if (splited[i][1] != '\0')
+			{
+				/* %text% */
+				temp[i] = splited[i];
+				st = 1;
+			}
+			else if(splited[i][0] == 't')
+			{
+				/* %t% */
+				temp[i] = (gchar*)kz_embed_get_title(KZ_EMBED(widget));
+				st = 2;
+			}
+			else if(splited[i][0] == 'u')
+			{
+				/* %u% */
+				temp[i] = (gchar*)kz_embed_get_location(KZ_EMBED(widget));
+				st = 2;
+			}
+			else if(splited[i][0] == 's')
+			{
+				/* %s% */
+				temp[i] = text;
+				st = 2;
+			}
+			else
+			{
+				/* '%' + other char + '%' */
+				temp[i] = splited[i];
+				st = 1;
+			}
+		}
+		temp[counts-1] = splited[counts-1];
+		temp[counts] = NULL;
+
+		str = g_strjoinv(NULL, temp);
+		g_strfreev(splited);
+	}
+	else
+	{
+		str = g_strdup(format);
+	}
+
+	g_free(format);
+
+	gtkutil_copy_text(str);
+
+	if(str) g_free(str);
+	if(text) g_free(text);
+}
 
 static void
 act_get_body_text (GtkAction *action, KzWindow *kz)
@@ -1873,6 +1973,7 @@ GtkActionEntry kz_actions[] =
   {"SelectAll", KZ_STOCK_SELECT_ALL,            N_("Select _All"),    CTRL"A", N_("Select the entire page"), G_CALLBACK(act_select_all)},
   {"CopyTitle",          NULL          ,        N_("Copy _Title"),    NULL,    N_("Copy the title of the current page"), G_CALLBACK(act_copy_title)},
   {"CopyURL",            KZ_STOCK_COPY_URL,     N_("Copy _URL"),      NULL,    N_("Copy the URL of the current page"), G_CALLBACK(act_copy_url)},
+  {"CopyInUserFormat",          NULL          ,        N_("Copy _In User Format"),    NULL,    N_("Copy Title, URI and Selected text in user format"), G_CALLBACK(act_copy_in_user_format)},
   {"Preference",         GTK_STOCK_PREFERENCES, N_("_Preference..."), NULL,    N_("Preference"), G_CALLBACK(act_preference)},
   {"DetailedPreference", NULL                 , N_("_Detailed Preference"), NULL, N_("Detailed preference"), G_CALLBACK(act_detaild_preference)},
 
