@@ -145,7 +145,9 @@ kz_location_entry_action_dispose (GObject *obj)
 
 	if (action->kz)
 	{
+		kz_profile_set_save_each_time(kz_global_profile, FALSE);
 		kz_location_entry_action_store_history(action);
+		kz_profile_set_save_each_time(kz_global_profile, TRUE);
 		g_object_unref(action->kz);
 		action->kz = NULL;
 	}
@@ -331,7 +333,9 @@ kz_location_entry_action_new (KzWindow *kz)
 			      "stock_id",    GTK_STOCK_NEW,
 			      "kz-window",   kz,
 			      NULL);
+	kz_profile_set_save_each_time(kz_global_profile, FALSE);
 	kz_location_entry_action_restore_history(action);
+	kz_profile_set_save_each_time(kz_global_profile, TRUE);
 
 	return action;
 }
