@@ -214,13 +214,13 @@ kz_smart_bookmark_action_set_property (GObject         *object,
 		if (kz_bookmark_is_folder(action->bookmark))
 		{
 			cb_bookmark_updated(action->bookmark, action);
-	/*		g_signal_connect(G_OBJECT(bookmark), "children-reordered",
+	/*		g_signal_connect(bookmark, "children-reordered",
 					 G_CALLBACK(cb_bookmark_updated),
 					 action);*/
-			g_signal_connect_after(G_OBJECT(action->bookmark), "insert-child",
+			g_signal_connect_after(action->bookmark, "insert-child",
 					 G_CALLBACK(cb_bookmark_insert_child),
 					 action);
-			g_signal_connect(G_OBJECT(action->bookmark), "remove-child",
+			g_signal_connect(action->bookmark, "remove-child",
 					 G_CALLBACK(cb_bookmark_remove_child),
 					 action);	
 		}
@@ -315,14 +315,14 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 		smart_action = KZ_SMART_BOOKMARK_ACTION(action);
 		bookmark = smart_action->bookmark;
-		g_signal_connect(G_OBJECT(entry), "key-press-event",
+		g_signal_connect(entry, "key-press-event",
 				 G_CALLBACK(cb_entry_key_press), action);
-		g_signal_connect(G_OBJECT(entry), "populate-popup",
+		g_signal_connect(entry, "populate-popup",
 				 G_CALLBACK(cb_entry_populate_popup), action);
-		g_signal_connect(G_OBJECT(entry), "icon-pressed",
+		g_signal_connect(entry, "icon-pressed",
 				 G_CALLBACK(cb_entry_icon_pressed), action);
 	
-		g_signal_connect(G_OBJECT(bookmark), "notify",
+		g_signal_connect(bookmark, "notify",
 			 	 G_CALLBACK(cb_bookmark_notify), action);
 		update_icon_and_bgtext(KZ_SMART_BOOKMARK_ACTION(action));
 	}
@@ -338,15 +338,15 @@ disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 	if (entry)
 	{
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(entry),
+			(entry,
 			 G_CALLBACK(cb_entry_key_press),
 			 action);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(entry),
+			(entry,
 			 G_CALLBACK(cb_entry_populate_popup),
 			 action);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(entry),
+			(entry,
 			 G_CALLBACK(cb_entry_icon_pressed),
 			 action);
 	}
@@ -452,7 +452,7 @@ cb_entry_populate_popup (GtkEntry *entry, GtkMenu *menu,
 	gtk_widget_show(separator);
 
 	menuitem = gtk_menu_item_new_with_mnemonic(_("_Edit Smart Bookmark"));
-	g_signal_connect(G_OBJECT(menuitem), "activate",
+	g_signal_connect(menuitem, "activate",
 			 G_CALLBACK(cb_activate_edit_bookmark), action);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 	gtk_widget_show(menuitem);
@@ -558,7 +558,7 @@ create_menu_item (KzSmartBookmarkAction *action, KzBookmark *bookmark)
 			  bookmark);
 	gtk_widget_show(menuitem);
 
-	g_signal_connect (G_OBJECT(menuitem), "activate",
+	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK(cb_menuitem_activate), action);
 	
 	return menuitem;
@@ -627,7 +627,7 @@ cb_bookmark_remove_child (KzBookmark *folder,
 	if (widget)
 	{
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(widget),
+			(widget,
 			 G_CALLBACK(cb_menuitem_activate),
 			 child);
 		gtk_widget_destroy(widget);
