@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.c,v 1.38 2004/10/30 00:32:48 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.c,v 1.40 2005/02/14 05:45:04 ikezoe Exp $
  */
 
 #include "kz-bookmark-editor.h"
@@ -191,7 +191,7 @@ kz_bookmark_editor_init (KzBookmarkEditor *editor)
 	gtk_container_add(GTK_CONTAINER(scrwin[0]), treeview[0]);
 	gtk_widget_show(treeview[0]);
 
-	g_signal_connect(G_OBJECT(treeview[0]), "cursor-changed",
+	g_signal_connect(treeview[0], "cursor-changed",
 			 G_CALLBACK(cb_folder_view_cursor_changed), editor);
 
 	/* vpaned */
@@ -214,12 +214,12 @@ kz_bookmark_editor_init (KzBookmarkEditor *editor)
 	gtk_container_add(GTK_CONTAINER(scrwin[1]), treeview[1]);
 	gtk_widget_show(treeview[1]);
 
-	g_signal_connect(G_OBJECT(treeview[1]), "cursor-changed",
+	g_signal_connect(treeview[1], "cursor-changed",
 			 G_CALLBACK(cb_bookmarks_view_cursor_changed), editor);
-	g_signal_connect(G_OBJECT(selection), "changed",
+	g_signal_connect(selection, "changed",
 			 G_CALLBACK(cb_bookmarks_view_selection_changed),
 			 editor);
-	g_signal_connect(G_OBJECT(treeview[1]), "button-press-event",
+	g_signal_connect(treeview[1], "button-press-event",
 			 G_CALLBACK(cb_bookmarks_view_button_press),
 			 editor);
 
@@ -340,8 +340,6 @@ kz_bookmark_editor_delete_event (GtkWidget *widget, GdkEventAny *event)
 {
 	KzBookmarkEditor *editor;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK_EDITOR(widget), FALSE);
-
 	editor = KZ_BOOKMARK_EDITOR(widget);
 	kz_bookmark_editor_store_state(editor);
 
@@ -568,7 +566,6 @@ cb_folder_view_cursor_changed (GtkTreeView *treeview, KzBookmarkEditor *editor)
 	GtkTreePath *path = NULL;
 	KzBookmark *folder;
 
-	g_return_if_fail(treeview);
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
 	kz_bookmark_edit_clear(KZ_BOOKMARK_EDIT(editor->content_view));
@@ -601,7 +598,6 @@ cb_bookmarks_view_cursor_changed (GtkTreeView *treeview,
 	GtkTreePath *path = NULL;
 	KzBookmark *bookmark = NULL;
 
-	g_return_if_fail(GTK_IS_TREE_VIEW(treeview));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
 	model = gtk_tree_view_get_model(treeview);
@@ -632,7 +628,6 @@ cb_bookmarks_view_selection_changed (GtkTreeSelection *selection,
 	GtkTreeIter iter;
 	gboolean selected;
 
-	g_return_if_fail(GTK_IS_TREE_SELECTION(selection));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
 	selected = gtk_tree_selection_get_selected(selection, &model, &iter);
