@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-file.c,v 1.14 2005/02/14 05:45:05 ikezoe Exp $
+ *  $Id: kz-bookmark-file.c,v 1.16 2005/04/07 12:29:22 ikezoe Exp $
  */
 
 #include "kz-bookmark-file.h"
@@ -59,7 +59,8 @@ enum {
 	PROP_XMLRPC,
 	PROP_XMLRPC_USER,
 	PROP_XMLRPC_PASS,
-	PROP_EDITABLE
+	PROP_EDITABLE,
+	PROP_PREVIOUS_LAST_MODIFIED
 };
 
 
@@ -114,8 +115,7 @@ static GQuark timer_quark             = 0;
 static GQuark state_quark             = 0;
 static GQuark io_quark                = 0;
 static GQuark io_signal_id_quark      = 0;
-
-
+static GQuark p_last_modified_quark   = 0;
 
 KZ_OBJECT_GET_TYPE(kz_bookmark_file, "KzBookmarkFile", KzBookmarkFile,
 		   kz_bookmark_file_class_init, kz_bookmark_file_init,
@@ -218,7 +218,18 @@ kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
 			 _("The password for XMLRPC"),
 			 NULL,
 			 G_PARAM_READWRITE));
-
+	
+	g_object_class_install_property(
+		object_class,
+		 PROP_PREVIOUS_LAST_MODIFIED,
+		 g_param_spec_uint(
+			 "previous-last-modified",
+			 _("Previous Last Modified"),
+			 _("The time of previous last modified"),
+			 0,
+			 G_MAXUINT,
+			 0,
+			 G_PARAM_READWRITE));
 
 	kz_bookmark_file_signals[LOAD_START_SIGNAL]
 		= g_signal_new("load_start",
@@ -270,16 +281,17 @@ kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
 			       g_cclosure_marshal_VOID__STRING,
 			       G_TYPE_NONE, 1, G_TYPE_STRING);
 
-	location_quark    = g_quark_from_string("KzBookmarkFile::BookmarkFileLocation");
-	file_type_quark   = g_quark_from_string("KzBookmarkFile::FileType");
-	interval_quark    = g_quark_from_string("KzBookmarkFile::Interval");
-	timer_quark       = g_quark_from_string("KzBookmarkFile::Timer");
-	state_quark       = g_quark_from_string("KzBookmarkFile::State");
-	io_quark          = g_quark_from_string("KzBookmarkFile::KzIO");
-	io_signal_id_quark= g_quark_from_string("KzBookmarkFile::KzIOSignalID");
-	xmlrpc_quark      = g_quark_from_string("KzBookmarkFile::XMLRPC");
-	xmlrpc_user_quark = g_quark_from_string("KzBookmarkFile::XMLRPCUser");
-	xmlrpc_pass_quark = g_quark_from_string("KzBookmarkFile::XMLRPCPassword");
+	location_quark        = g_quark_from_string("KzBookmarkFile::BookmarkFileLocation");
+	file_type_quark       = g_quark_from_string("KzBookmarkFile::FileType");
+	interval_quark        = g_quark_from_string("KzBookmarkFile::Interval");
+	timer_quark           = g_quark_from_string("KzBookmarkFile::Timer");
+	state_quark           = g_quark_from_string("KzBookmarkFile::State");
+	io_quark              = g_quark_from_string("KzBookmarkFile::KzIO");
+	io_signal_id_quark    = g_quark_from_string("KzBookmarkFile::KzIOSignalID");
+	xmlrpc_quark          = g_quark_from_string("KzBookmarkFile::XMLRPC");
+	xmlrpc_user_quark     = g_quark_from_string("KzBookmarkFile::XMLRPCUser");
+	xmlrpc_pass_quark     = g_quark_from_string("KzBookmarkFile::XMLRPCPassword");
+	p_last_modified_quark = g_quark_from_string("KzBookmarkFile::PreviousLastModified");
 }
 
 
@@ -412,6 +424,15 @@ kz_bookmark_file_set_property (GObject *object,
 	case PROP_XMLRPC_PASS:
 		CHANGE_STR(object, xmlrpc_pass_quark, g_value_dup_string(value));
 		break;
+	case PROP_PREVIOUS_LAST_MODIFIED:
+	{
+		guint t;
+
+		t = g_value_get_uint(value);
+		g_object_set_qdata(object, p_last_modified_quark,
+				   GUINT_TO_POINTER(t));
+		break;
+	}
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -464,6 +485,14 @@ kz_bookmark_file_get_property (GObject *object,
 		str = g_object_get_qdata(object, xmlrpc_pass_quark);
 		g_value_set_string(value, str);
 		break;
+	case PROP_PREVIOUS_LAST_MODIFIED:
+	{
+		guint t;
+
+		t = GPOINTER_TO_UINT(g_object_get_qdata(object, p_last_modified_quark));
+		g_value_set_uint(value, t);
+		break;
+	}
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -481,10 +510,11 @@ kz_bookmark_file_new (const gchar *location,
 	location = location ? location : "";
 
 	bookmark_file = g_object_new(KZ_TYPE_BOOKMARK_FILE,
-				     "type",      KZ_BOOKMARK_FOLDER,
-				     "location",  location,
-				     "title",     title,
-				     "file-type", file_type,
+				     "type",                   KZ_BOOKMARK_FOLDER,
+				     "location",               location,
+				     "title",                  title,
+				     "file-type",              file_type,
+				     "previous-last-modified", 0,
 				     NULL);
 
 	return bookmark_file;
@@ -664,7 +694,7 @@ kz_bookmark_file_load_start (KzBookmarkFile *bookmark_file)
 {
 	KzIO *io;
 	const gchar *uri;
-	guint id;
+	guint id, last_mod;
 	KzBookmarkFileState state;
 
 	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark_file), FALSE);
@@ -682,6 +712,9 @@ kz_bookmark_file_load_start (KzBookmarkFile *bookmark_file)
 		return TRUE;
 	kz_bookmark_file_set_state(bookmark_file, KZ_BOOKMARK_FILE_STATE_LOADING);
 
+	last_mod = kz_bookmark_get_last_modified(KZ_BOOKMARK(bookmark_file));
+	g_object_set(bookmark_file, "previous-last-modified", last_mod, NULL);
+
 	g_signal_emit(bookmark_file,
 		      kz_bookmark_file_signals[LOAD_START_SIGNAL],
 		      0);
@@ -692,7 +725,7 @@ kz_bookmark_file_load_start (KzBookmarkFile *bookmark_file)
 	id = g_signal_connect(io, "io_completed",
 			      G_CALLBACK(cb_io_load_complete),
 			      bookmark_file);
-	
+
 	g_object_set_qdata(G_OBJECT(bookmark_file), io_quark, io);
 	g_object_set_qdata(G_OBJECT(bookmark_file), io_signal_id_quark,
 			   GUINT_TO_POINTER(id));
@@ -1089,3 +1122,27 @@ kz_bookmark_file_xmlrpc_move (KzBookmarkFile *file,
 			folder_id, sibling_id,
 			NULL);
 }
+
+	
+guint
+kz_bookmark_file_get_previous_last_modified (KzBookmarkFile *bookmark_file)
+{
+	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark_file), 0);
+
+	return GPOINTER_TO_UINT(g_object_get_qdata(G_OBJECT(bookmark_file),
+						   p_last_modified_quark));
+}
+
+gboolean
+kz_bookmark_file_is_update (KzBookmarkFile *bookmark_file)
+{
+	guint last_time, time;
+	
+	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark_file), FALSE);
+
+	last_time = kz_bookmark_file_get_previous_last_modified(bookmark_file);
+	time = kz_bookmark_get_last_modified(KZ_BOOKMARK(bookmark_file));
+
+	return last_time < time ? TRUE : FALSE;
+}
+
