@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu.c,v 1.3 2005/02/13 13:20:34 ikezoe Exp $
+ *  $Id: kz-bookmark-menu.c,v 1.6 2005/04/21 20:47:45 ikezoe Exp $
  */
 
 #include "kz-bookmark-menu.h"
@@ -69,6 +69,7 @@ kz_bookmark_menu_create_menuitem (KzBookmark *bookmark, KzWindow *kz,
 	GtkWidget *menu_item;
 	const gchar *title = NULL, *desc;
 	gchar *tooltip_text = NULL;
+	gint bookmark_max_strnum = 0;
 	GtkTooltips *tooltip = NULL;
 	GtkWidget *favicon;
 	KzFavicon *kzfav;
@@ -99,7 +100,24 @@ kz_bookmark_menu_create_menuitem (KzBookmark *bookmark, KzWindow *kz,
 	if (desc)
 		tooltip_text = remove_tag(desc, strlen(desc));
 	
-	menu_item = gtk_image_menu_item_new_with_label(title);
+	KZ_CONF_GET("Global" , "bookmark_cutoff_strnum" , bookmark_max_strnum , INT);
+
+	if(bookmark_max_strnum> 0 && (g_utf8_strlen(title , -1) > bookmark_max_strnum))
+	{
+		gint len = g_utf8_offset_to_pointer(title, bookmark_max_strnum) - title;
+		gchar *short_title = g_alloca (len + 3 + 1);
+		/* 3 for "..." , 1 for '\0' */
+
+		g_utf8_strncpy(short_title , title , bookmark_max_strnum);
+		short_title[len-3] = '.';
+		short_title[len-2] = '.';
+		short_title[len-1] = '.';
+		short_title[len] = '\0';
+		menu_item = gtk_image_menu_item_new_with_label(short_title);
+	}
+	else
+		menu_item = gtk_image_menu_item_new_with_label(title);
+
 	g_object_set_data(G_OBJECT(menu_item),
 			  KZ_BOOKMARK_MENU_BOOKMARK_KEY,
 			  bookmark);
@@ -442,17 +460,7 @@ cb_menu_item_activate (GtkWidget *widget, KzWindow *kz)
 	switch (button)
 	{
 	case 2:
-		if (kz_bookmark_is_folder(item))
-		{
-			GtkAction *action;
-			kz_actions_set_bookmark_for_action(kz, item);
-			action = gtk_action_group_get_action(kz->actions,
-							     "OpenAllBookmarks");
-			if (action)
-				gtk_action_activate(action);
-			kz_actions_set_bookmark_for_action(kz, NULL);
-		}
-		else if (uri)
+		if (uri)
 			kz_window_open_new_tab(kz, uri);
 		break;
 	default:
@@ -513,18 +521,7 @@ cb_menu_item_button_release (GtkWidget *widget, GdkEventButton *event,
 		KZ_CONF_GET("Global", "keep_bookmark_menu", keep, BOOL);
 		if (!keep)
 			return FALSE;
-
-		if (kz_bookmark_is_folder(item))
-		{
-			GtkAction *action;
-			kz_actions_set_bookmark_for_action(kz, item);
-			action = gtk_action_group_get_action(kz->actions,
-							     "OpenAllBookmarks");
-			if (action)
-				gtk_action_activate(action);
-			kz_actions_set_bookmark_for_action(kz, NULL);
-		}
-		else if (uri)
+		if (uri)
 			kz_window_open_new_tab(kz, uri);
 		/* reset release button state */
 		button = 0;
