@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.h,v 1.31 2004/11/25 07:28:47 ikezoe Exp $
+ *  $Id: kz-bookmark.h,v 1.32 2004/12/05 08:06:06 tyuyu Exp $
  */
 
 #ifndef __KZ_BOOKMARK_H__
@@ -154,6 +154,9 @@ void		kz_bookmark_set_current		(KzBookmark  *bookmark,
 gboolean	kz_bookmark_get_lock		(KzBookmark  *bookmark);
 void		kz_bookmark_set_lock		(KzBookmark  *bookmark,
 						 gboolean lock);
+gboolean	kz_bookmark_get_auto_refresh	(KzBookmark  *bookmark);
+void		kz_bookmark_set_auto_refresh	(KzBookmark  *bookmark,
+						 gboolean auto_refresh);
 
 void		kz_bookmark_regist_sort_func	(const gchar *type,
 						 GCompareFunc *func);
