@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.24 2005/02/14 05:45:05 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.25 2005/04/22 04:44:38 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
@@ -1041,7 +1041,7 @@ cb_drag_data_get (GtkWidget *widget,
 	{
 	case TARGET_KAZEHAKASE_BOOKMARKS:
 		gtk_selection_data_set(seldata, seldata->target,
-				       8, "dummy", strlen("dummy"));
+				       8, (const guchar*)"dummy", strlen("dummy"));
 		break;
 	}
 }
