@@ -21,7 +21,7 @@
 #ifndef __KZ_HINADI_H__
 #define __KZ_HINADI_H__
 
-#include "kz-bookmark.h"
+#include "kz-bookmark-file.h"
 
 G_BEGIN_DECLS
 
