@@ -30,18 +30,18 @@
 #include <stdlib.h>
 #include <time.h>
 
-static gboolean kz_rss_is_supported      (KzBookmark  *bookmark,
-					  const gchar *buffer);
-static gboolean kz_rss_parse_from_string (KzBookmark  *bookmark,
-					  const gchar *buffer,
-					  guint        length,
-					  GError     **error);
-static gchar   *kz_rss_get_encoding      (gchar       *src);
-static gchar   *kz_rss_convert_to_utf8   (gchar       *src,
-					  guint        src_len,
-					  gsize       *dest_len);
-static void     kz_rss_parse_xml         (KzBookmark *bookmark, 
-					  KzXML *xml);
+static gboolean kz_rss_is_supported      (KzBookmarkFile *bookmark,
+					  const gchar    *buffer);
+static gboolean kz_rss_parse_from_string (KzBookmarkFile *bookmark,
+					  const gchar    *buffer,
+					  guint           length,
+					  GError        **error);
+static gchar   *kz_rss_get_encoding      (gchar          *src);
+static gchar   *kz_rss_convert_to_utf8   (gchar          *src,
+					  guint           src_len,
+					  gsize          *dest_len);
+static void     kz_rss_parse_xml         (KzBookmark     *bookmark, 
+					  KzXML          *xml);
 
 static KzBookmarkFileType rss_file_type =
 {
@@ -65,7 +65,7 @@ kz_rss_get_file_types (gint idx)
 
 
 static gboolean
-kz_rss_is_supported(KzBookmark *bookmark, const gchar *buf)
+kz_rss_is_supported(KzBookmarkFile *bookmark, const gchar *buf)
 {
 	const gchar *pos;
 
@@ -90,7 +90,7 @@ kz_rss_is_supported(KzBookmark *bookmark, const gchar *buf)
 
 
 static gboolean
-kz_rss_parse_from_string (KzBookmark *bookmark,
+kz_rss_parse_from_string (KzBookmarkFile *bookmark,
 			  const gchar *buffer, guint length,
 			  GError **error)
 {
@@ -98,7 +98,7 @@ kz_rss_parse_from_string (KzBookmark *bookmark,
 	gchar *utf8_body = NULL;
 	gsize utf8_len;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
+	g_return_val_if_fail(KZ_IS_BOOKMARK_FILE(bookmark), FALSE);
 
 	g_return_val_if_fail(buffer != NULL, FALSE);
 
@@ -116,7 +116,7 @@ kz_rss_parse_from_string (KzBookmark *bookmark,
 		return FALSE;
 	}
 
-	kz_rss_parse_xml(bookmark, xml);
+	kz_rss_parse_xml(KZ_BOOKMARK(bookmark), xml);
 
 	g_free(utf8_body);
 
