@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.60 2005/02/05 11:02:51 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.61 2005/02/13 13:20:34 ikezoe Exp $
  */
 
 #include "kazehakase.h"
@@ -138,11 +138,11 @@ kz_xbel_init (KzBookmarkFile *bookmark)
 		     "type", KZ_BOOKMARK_PURE_FOLDER,
 		     NULL);
 
-	g_signal_connect(G_OBJECT(bookmark), "notify",
+	g_signal_connect(bookmark, "notify",
 			 G_CALLBACK(kz_xbel_notify), xml);
-	g_signal_connect_after(G_OBJECT(bookmark), "insert-child",
+	g_signal_connect_after(bookmark, "insert-child",
 			       G_CALLBACK(cb_bookmark_insert_child), xml);
-	g_signal_connect_after(G_OBJECT(bookmark), "remove-child",
+	g_signal_connect_after(bookmark, "remove-child",
 			       G_CALLBACK(cb_bookmark_remove_child), xml);
 }
 
@@ -1033,17 +1033,17 @@ create_xml_node (KzBookmark *bookmark)
 static void
 kz_xbel_connect_signals (KzBookmark *bookmark)
 {
-	g_signal_connect(G_OBJECT(bookmark), "notify",
+	g_signal_connect(bookmark, "notify",
 			 G_CALLBACK(cb_bookmark_notify), NULL);
 
 	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
 	if (!kz_bookmark_is_folder(bookmark)) return;
 
 	{
-		g_signal_connect_after(G_OBJECT(bookmark), "insert-child",
+		g_signal_connect_after(bookmark, "insert-child",
 				       G_CALLBACK(cb_bookmark_insert_child),
 				       NULL);
-		g_signal_connect_after(G_OBJECT(bookmark), "remove-child",
+		g_signal_connect_after(bookmark, "remove-child",
 				       G_CALLBACK(cb_bookmark_remove_child),
 				       NULL);
 	}
@@ -1067,7 +1067,7 @@ static void
 kz_xbel_disconnect_signals (KzBookmark *bookmark)
 {
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bookmark),
+		(bookmark,
 		 G_CALLBACK(cb_bookmark_notify), NULL);
 
 	if (KZ_IS_BOOKMARK_FILE(bookmark)) return;
@@ -1075,10 +1075,10 @@ kz_xbel_disconnect_signals (KzBookmark *bookmark)
 
 	{
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(bookmark),
+			(bookmark,
 			 G_CALLBACK(cb_bookmark_insert_child), NULL);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(bookmark),
+			(bookmark,
 			 G_CALLBACK(cb_bookmark_remove_child), NULL);
 	}
 
