@@ -170,8 +170,6 @@ kz_downloader_dispose (GObject *object)
 {
 	KzDownloader *downloader;
 
-	g_return_if_fail(KZ_IS_DOWNLOADER(object));
-
 	downloader = KZ_DOWNLOADER(object);
 	if (downloader->io)
 		g_object_unref(downloader->io);
@@ -254,10 +252,10 @@ kz_downloader_new (const gchar *uri)
 	if(!io)
 		return NULL;
 	
-	dl = KZ_DOWNLOADER(g_object_new(KZ_TYPE_DOWNLOADER,
-					"uri", uri,
-					"io",  io,
-					NULL));
+	dl = g_object_new(KZ_TYPE_DOWNLOADER,
+		 	  "uri", uri,
+			  "io",  io,
+			  NULL);
 
 	g_object_unref(io);
 
@@ -275,11 +273,11 @@ kz_downloader_new_with_filename (const gchar *uri, const gchar *filename)
 	if(!io)
 		return NULL;
 	
-	dl = KZ_DOWNLOADER(g_object_new(KZ_TYPE_DOWNLOADER,
-					"uri",      uri,
-					"filename", filename,
-					"io",       io,
-					NULL));
+	dl = g_object_new(KZ_TYPE_DOWNLOADER,
+			  "uri",      uri,
+			  "filename", filename,
+			  "io",       io,
+			  NULL);
 	g_object_unref(io);
 
 	return dl;
@@ -289,9 +287,9 @@ kz_downloader_new_with_filename (const gchar *uri, const gchar *filename)
 static void
 kz_downloader_connect_signals (KzDownloader *downloader)
 {
-	g_signal_connect(G_OBJECT(downloader->io), "io_completed",
+	g_signal_connect(downloader->io, "io_completed",
 			 G_CALLBACK(cb_completed), downloader);
-	g_signal_connect(G_OBJECT(downloader->io), "io_progress",
+	g_signal_connect(downloader->io, "io_progress",
 			 G_CALLBACK(cb_io_in), downloader);
 }
 
@@ -299,10 +297,10 @@ kz_downloader_connect_signals (KzDownloader *downloader)
 static void
 kz_downloader_disconnect_signals (KzDownloader *downloader)
 {
-	g_signal_handlers_disconnect_by_func(G_OBJECT(downloader->io),
+	g_signal_handlers_disconnect_by_func(downloader->io,
 					     G_CALLBACK(cb_completed),
 					     downloader);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(downloader->io),
+	g_signal_handlers_disconnect_by_func(downloader->io,
 					     G_CALLBACK(cb_io_in),
 					     downloader);
 }
@@ -316,13 +314,13 @@ cb_completed(KzIO *io, GError *error, KzDownloader *downloader)
 	kz_downloader_disconnect_signals(downloader);
 	if (error)
 	{
-		g_signal_emit(G_OBJECT(downloader),
+		g_signal_emit(downloader,
 			      kz_downloader_signals[ERROR_SIGNAL],
 			      0);
 	}
 	else
 	{
-		g_signal_emit(G_OBJECT(downloader),
+		g_signal_emit(downloader,
 			      kz_downloader_signals[COMPLETED_SIGNAL],
 			      0);
 	}
@@ -335,7 +333,7 @@ cb_io_in(KzIO *io, guint len, const gchar *buf, KzDownloader *downloader)
 	g_return_if_fail(KZ_IS_DOWNLOADER(downloader));
 
 	/* emit progress signal */
-	g_signal_emit(G_OBJECT(downloader),
+	g_signal_emit(downloader,
 		      kz_downloader_signals[IO_IN_SIGNAL],
 		      0);	
 }
