@@ -963,6 +963,46 @@ kz_embed_page_up (KzEmbed *kzembed)
 }
 
 
+void
+kz_embed_set_allow_javascript (KzEmbed *kzembed, gboolean allow)
+{
+	g_return_if_fail(KZ_IS_EMBED(kzembed));
+	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->set_allow_javascript);
+
+	KZ_EMBED_GET_IFACE(kzembed)->set_allow_javascript(kzembed, allow);
+}
+
+
+gboolean
+kz_embed_get_allow_javascript (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
+	g_return_val_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_allow_javascript, FALSE);
+
+	return KZ_EMBED_GET_IFACE(kzembed)->get_allow_javascript(kzembed);
+}
+
+
+void
+kz_embed_set_allow_images (KzEmbed *kzembed, gboolean allow)
+{
+	g_return_if_fail(KZ_IS_EMBED(kzembed));
+	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->set_allow_images);
+
+	KZ_EMBED_GET_IFACE(kzembed)->set_allow_images(kzembed, allow);
+}
+
+
+gboolean
+kz_embed_get_allow_images (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
+	g_return_val_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_allow_images, FALSE);
+
+	return KZ_EMBED_GET_IFACE(kzembed)->get_allow_images(kzembed);
+}
+
+
 static gchar *
 kz_embed_get_up_location(KzEmbed *kzembed)
 {
