@@ -214,6 +214,13 @@ struct _KzEmbedIFace {
 						 int            vert);
 	void		(*page_down)		(KzEmbed       *kzembed);
 	void		(*page_up)		(KzEmbed       *kzembed);
+	
+	gboolean	(*get_allow_javascript)	(KzEmbed       *kzembed);
+	void		(*set_allow_javascript)	(KzEmbed       *kzembed,
+	    					 gboolean	allow);
+	gboolean	(*get_allow_images)	(KzEmbed       *kzembed);
+	void		(*set_allow_images)	(KzEmbed       *kzembed,
+	    					 gboolean	allow);
 
 	/* signals */
 	void     (*link_message)        (KzEmbed      *embed);
@@ -401,8 +408,15 @@ void		kz_embed_set_view_mode		(KzEmbed       *kzembed);
 void            kz_embed_fine_scroll            (KzEmbed       *kzembed,
 						 int            horiz,
 						 int            vert);
-void		kz_embed_page_up		(KzEmbed       *kzembed);	
-void		kz_embed_page_down		(KzEmbed       *kzembed);	
+void		kz_embed_page_up		(KzEmbed       *kzembed);
+void		kz_embed_page_down		(KzEmbed       *kzembed);
+
+gboolean	kz_embed_get_allow_javascript	(KzEmbed       *kzembed);
+void		kz_embed_set_allow_javascript	(KzEmbed       *kzembed,
+    						 gboolean	allow);
+gboolean	kz_embed_get_allow_images	(KzEmbed       *kzembed);
+void		kz_embed_set_allow_images	(KzEmbed       *kzembed,
+    						 gboolean	allow);
 
 G_END_DECLS
 
