@@ -41,6 +41,7 @@
 #include "prefs_ui/prefs_privacy.h"
 #include "prefs_ui/prefs_external_program.h"
 #include "prefs_ui/prefs_history.h"
+#include "prefs_ui/prefs_bookmark.h"
 
 
 enum {
@@ -137,11 +138,12 @@ kz_prefs_win_class_init (KzPrefsWinClass *klass)
 	ADD_PAGE_ENTRY(prefs_font_get_entry);
 	ADD_PAGE_ENTRY(prefs_tab_get_entry);
 	ADD_PAGE_ENTRY(prefs_entry_get_entry);
+	ADD_PAGE_ENTRY(prefs_bookmark_get_entry);
 	ADD_PAGE_ENTRY(prefs_key_accel_get_entry);
 	ADD_PAGE_ENTRY(prefs_gesture_get_entry);
 	ADD_PAGE_ENTRY(prefs_proxy_get_entry);
 	ADD_PAGE_ENTRY(prefs_privacy_get_entry); 
-	ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); 
+	/* ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); */
 	ADD_PAGE_ENTRY(prefs_external_program_get_entry);
 	ADD_PAGE_ENTRY(prefs_history_get_entry);
 }
