@@ -237,10 +237,6 @@ static void     cb_sidebar_map                (GtkWidget       *widget,
 					       GtkToggleAction *action);
 static void     cb_sidebar_unmap              (GtkWidget       *widget,
 					       GtkToggleAction *action);
-static void     cb_bookmarkbars_map           (GtkWidget       *widget,
-					       GtkToggleAction *action);
-static void     cb_bookmarkbars_unmap         (GtkWidget       *widget,
-					       GtkToggleAction *action);
 static gboolean cb_focus_out_event            (GtkWidget       *widget,
 					       GdkEventFocus   *event,
 					       KzWindow        *kz);
@@ -593,12 +589,6 @@ kz_window_init (KzWindow *kz)
 					 G_CALLBACK(cb_sidebar_map), action);
 			g_signal_connect(kz->sidebar, "unmap",
 					 G_CALLBACK(cb_sidebar_unmap), action);
-			action = gtk_action_group_get_action(kz->actions,
-							     "ShowHideBookmarkbars");
-			g_signal_connect(kz->bookmark_bars_area, "map",
-					 G_CALLBACK(cb_bookmarkbars_map), action);
-			g_signal_connect(kz->bookmark_bars_area, "unmap",
-					 G_CALLBACK(cb_bookmarkbars_unmap), action);
 		}
 
 		/* embed tab */
@@ -1688,7 +1678,7 @@ kz_window_store_state (KzWindow *kz)
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-
+	kz_profile_set_save_each_time(kz_global_profile, FALSE);
 	/*
 	 * window size
 	 */
@@ -1768,6 +1758,8 @@ kz_window_store_state (KzWindow *kz)
 		}
 	}
 
+	kz_profile_set_save_each_time(kz_global_profile, TRUE);
+	kz_profile_save(kz_global_profile);
 
 	/*
 	 *  Session
@@ -2647,26 +2639,6 @@ cb_sidebar_unmap (GtkWidget *widget, GtkToggleAction *action)
 }
 
 
-
-static void
-cb_bookmarkbars_map (GtkWidget *widget, GtkToggleAction *action)
-{
-	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
-
-	gtk_toggle_action_set_active(action, TRUE);
-}
-
-
-static void
-cb_bookmarkbars_unmap (GtkWidget *widget, GtkToggleAction *action)
-{
-	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
-
-	gtk_toggle_action_set_active(action, FALSE);
-}
-
-
-
 /*****************************************************************************
  *                                                                           *
  *                        Callbacks for Embed                                *
@@ -2711,7 +2683,7 @@ cb_embed_location_changed (KzEmbed *embed, KzWindow *kz)
 		/* g_print("failed to get location!\n"); */
 	}
 
-	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_sensitive(kz, embed);
 }
 
 
@@ -2738,24 +2710,18 @@ cb_embed_link_message (KzEmbed *embed, KzWindow *kz)
 static void
 cb_embed_load_started (KzEmbed *embed, KzWindow *kz)
 {
-	KzEmbed *kzembed;
-
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
-	kz_actions_set_sensitive(kz, kzembed);
+	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
 }
 
 
 static void
 cb_embed_load_finished (KzEmbed *embed, KzWindow *kz)
 {
-	KzEmbed *kzembed;
-
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
-	kz_actions_set_sensitive(kz, kzembed);
+	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
 }
 
 
@@ -2818,7 +2784,7 @@ cb_embed_dom_key_down (KzEmbed *embed, KzEmbedEventKey *event, KzWindow *kz)
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
-	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_sensitive(kz, embed);
 
 	return FALSE;
 }
@@ -2829,7 +2795,7 @@ cb_embed_dom_key_up (KzEmbed *embed, KzEmbedEventKey *event, KzWindow *kz)
 {
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
-	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_sensitive(kz, embed);
 
 	return FALSE;
 }
@@ -3060,7 +3026,7 @@ cb_embed_dom_mouse_down (KzEmbed *kzembed, KzEmbedEventMouse *event,
 		break;
 	}
 
-	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_selection_sensitive(kz, kzembed);
 
 	return FALSE;
 }
@@ -3072,14 +3038,14 @@ cb_embed_dom_mouse_up (KzEmbed *embed, KzEmbedEventMouse *event,
 {
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
-	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_selection_sensitive(kz, embed);
 
 	return FALSE;
 }
 
 static gint
 cb_embed_dom_mouse_over (KzEmbed *embed, KzEmbedEventMouse *event,
-		       KzWindow *kz)
+		         KzWindow *kz)
 {
 	static glong previous_event_context = KZ_CONTEXT_NONE;
 	glong type;
@@ -3108,7 +3074,7 @@ cb_embed_dom_mouse_over (KzEmbed *embed, KzEmbedEventMouse *event,
 	}
 
 	previous_event_context = type;
-	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_selection_sensitive(kz, embed);
 
 	return FALSE;
 }
@@ -3160,7 +3126,7 @@ cb_window_motion_notify_event (GtkWidget *widget,
 		*/
 	}
 
-	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
+	kz_actions_set_selection_sensitive(kz, kzembed);
 
 	return FALSE;
 }
@@ -3285,7 +3251,9 @@ cb_focus_out_event            (GtkWidget       *widget,
 			       GdkEventFocus   *event,
 			       KzWindow        *kz)
 {
-	if(!event->in) {/* focus is out */
+	if(!event->in) 
+	{
+		/* focus is out */
 		if (kz_gesture_is_started(kz->priv->gesture))
 		{
 			kz_gesture_cancel(kz->priv->gesture);
