@@ -24,15 +24,13 @@
 
 #include <gtk/gtk.h>
 
-#include "gtk24backports.h"
 #include "kz-gesture.h"
 #include "kz-embed-event.h"
+#include "kz-embed.h"
 #include "kz-favicon.h"
-#include "kz-mozembed.h"
+#include "kz-popup-preview.h"
 #include "kz-bookmark.h"
 
-#include "kz-mozthumbnailcreator.h"
-
 G_BEGIN_DECLS
 
 #define KZ_TYPE_WINDOW			(kz_window_get_type ())
@@ -52,6 +50,9 @@ struct _KzWindow
 
 	GtkWidget  *top_vbox;
 
+	/* menu and toolbar */
+	GtkWidget  *menu_box;
+
 	/* top of the window */
 	GtkWidget  *bookmark_bars_area;
 	GList      *bookmark_bars;
@@ -76,16 +77,18 @@ struct _KzWindow
 	GtkUIManager   *menu_merge;
 
 	/* bookmarks */
+	KzBookmark *tabs;
 	KzBookmark *closed_tabs;
 	KzBookmark *history_search;
 
 	/* handle for favicon */
 	KzFavicon *kzfav;
+	KzPopupPreview *popup;
+	GtkWidget *popup_tablist;
+
+	gboolean   is_closing_all;
 
 	KzWindowPriv *priv;
-	
-	/* for creating thumbnails */
-	KzMozThumbnailCreator *thumb_creator;
 };
 
 struct _KzWindowClass
@@ -103,7 +106,7 @@ struct _KzWindowClass
 			     gint       pos);
 };
 
-GtkType	          kz_window_get_type                 (void);
+GType	          kz_window_get_type                 (void) G_GNUC_CONST;
 GList            *kz_window_get_window_list          (void);
 GtkWidget        *kz_window_new                      (const gchar *url);
 GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
@@ -137,8 +140,7 @@ GNode            *kz_window_get_tree                 (KzWindow    *kz);
 const KzEmbedEventMouse *
 		  kz_window_get_mouse_event_info     (KzWindow    *kz);
 
-void		  kz_window_create_thumbnail_creator (KzWindow    *kz);
-
+void kz_window_append_closed_tab (KzWindow *kz, KzBookmark *bookmark);
 
 #define KZ_WINDOW_NTH_PAGE(kz, n) \
 	(KZ_IS_WINDOW(kz) ? gtk_notebook_get_nth_page(GTK_NOTEBOOK(KZ_WINDOW(kz)->notebook),n) : NULL)
