@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c,v 1.23 2004/10/15 03:38:58 makeinu Exp $
+ *  $Id: kz-xml.c,v 1.24 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-xml.h"
@@ -98,7 +98,7 @@ kz_xml_dispose (GObject *object)
 KzXML *
 kz_xml_new (void)
 {
-	KzXML *xml = KZ_XML(g_object_new(KZ_TYPE_XML, NULL));
+	KzXML *xml = g_object_new(KZ_TYPE_XML, NULL);
 	return xml;
 }
 
