@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.h,v 1.9 2004/10/15 04:39:01 makeinu Exp $
+ *  $Id: kz-xml.h,v 1.10 2004/11/25 07:28:47 ikezoe Exp $
  */
 
 #ifndef KZ_XML_H
@@ -96,7 +96,7 @@ struct _KzXMLAttr
 };
 
 /* XML file */
-GType        kz_xml_get_type               (void);
+GType        kz_xml_get_type               (void) G_GNUC_CONST;
 KzXML       *kz_xml_new                    (void);
 gboolean     kz_xml_load                   (KzXML         *xml,
 					    const gchar   *filename);
