@@ -40,7 +40,7 @@
 
 #include "eggmd5.h"
 #include "egg-pixbuf-thumbnail.h"
-#include "intl.h"
+#include <glib/gi18n.h>
 
 /* FIXME: #include "gdk-pixbuf-private.h" */
 
