@@ -1,5 +1,4 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/* vim:expandtab:shiftwidth=8:tabstop=8: */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -40,7 +39,9 @@
 #include "GtkPromptService.h"
 #include "EmbedPrompter.h"
 #include "kz-mozutils.h"
-#include <nsString.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIWindowWatcher.h>
 #include <nsIWebBrowserChrome.h>
 #include <nsIEmbeddingSiteWindow.h>
@@ -51,6 +52,7 @@
 #include <nsIDOMWindow.h>
 #include <nsIDOMCharacterData.h>
 #include <nsIDOMText.h>
+#include <nsMemory.h>
 
 GtkPromptService::GtkPromptService()
 {
@@ -66,10 +68,16 @@ NS_IMETHODIMP
 GtkPromptService::Alert(nsIDOMWindow* aParent, const PRUnichar* aDialogTitle, 
 		const PRUnichar* aDialogText)
 {
-	if ((strstr(NS_ConvertUCS2toUTF8(aDialogText).get(), "print preview")) ||
-	    (strstr(NS_ConvertUCS2toUTF8(aDialogTitle).get(), "Printer Error")))
+	nsEmbedCString cText, cTitle;
+	NS_UTF16ToCString(nsEmbedString(aDialogText),
+			  NS_CSTRING_ENCODING_UTF8, cText);
+	NS_UTF16ToCString(nsEmbedString(aDialogTitle),
+			  NS_CSTRING_ENCODING_UTF8, cTitle);
+	
+        if ((strstr(cText.get(), "print preview")) ||
+	    (strstr(cTitle.get(), "Printer Error")))
 	{
-		g_warning("%s", NS_ConvertUCS2toUTF8(aDialogText).get());
+		g_warning("%s", cText.get());
 		return NS_OK;
 	}
 #if 0
@@ -166,7 +174,7 @@ GtkPromptService::ConfirmEx(nsIDOMWindow* aParent,
 	prompter.SetTitle(aDialogTitle ? aDialogTitle : confirm);
 	prompter.SetMessageText(aDialogText);
 
-	nsAutoString button0Label, button1Label, button2Label;
+	nsEmbedString button0Label, button1Label, button2Label;
 	GetButtonLabel(aButtonFlags, BUTTON_POS_0, aButton0Title, button0Label);
 	GetButtonLabel(aButtonFlags, BUTTON_POS_1, aButton1Title, button1Label);
 	GetButtonLabel(aButtonFlags, BUTTON_POS_2, aButton2Title, button2Label);
@@ -318,30 +326,37 @@ GtkPromptService::GetButtonLabel(PRUint32 aFlags, PRUint32 aPos,
 	switch (posFlag) 
 	{
 		case BUTTON_TITLE_OK:
-			aLabel = NS_LITERAL_STRING(GTK_STOCK_OK);
+                        NS_CStringToUTF16(nsEmbedCString(GTK_STOCK_OK),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_CANCEL:
-			aLabel = NS_LITERAL_STRING(GTK_STOCK_CANCEL);
+                        NS_CStringToUTF16(nsEmbedCString(GTK_STOCK_CANCEL),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_YES:
-			aLabel = NS_LITERAL_STRING(GTK_STOCK_YES);
+                        NS_CStringToUTF16(nsEmbedCString(GTK_STOCK_YES),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_NO:
-			aLabel = NS_LITERAL_STRING(GTK_STOCK_NO);
+                        NS_CStringToUTF16(nsEmbedCString(GTK_STOCK_NO),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_SAVE:
-			aLabel = NS_LITERAL_STRING(GTK_STOCK_SAVE);
+                        NS_CStringToUTF16(nsEmbedCString(GTK_STOCK_SAVE),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_DONT_SAVE:
-			aLabel = NS_LITERAL_STRING("Don't Save");
+                        NS_CStringToUTF16(nsEmbedCString("Don't Save"),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_REVERT:
-			aLabel = NS_LITERAL_STRING("Revert");
+                        NS_CStringToUTF16(nsEmbedCString("Revert"),
+                                          NS_CSTRING_ENCODING_UTF8, aLabel);
 			break;
 		case BUTTON_TITLE_IS_STRING:
-			aLabel = aStringValue;
+			aLabel = nsEmbedString(aStringValue);
 			break;
-		default:
+                default:
 			NS_WARNING("Unexpected button flags");
 	}
 }
