@@ -38,7 +38,9 @@
  * ***** END LICENSE BLOCK ***** */
 
 #include <nsIPromptService.h>
-#include <nsString.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <gtk/gtk.h>
 
 #define NS_PROMPTSERVICE_CID \
