@@ -49,7 +49,6 @@
 #include <nsIWebBrowser.h>
 #include <nsIDOMMouseEvent.h>
 #include <dom/nsIDOMKeyEvent.h>
-#include <nsIDOMEventTarget.h>
 #include <dom/nsIDOMNSHTMLElement.h>  
 #include <nsIDOMHTMLElement.h>  
 #include <nsIDOMHTMLDocument.h>  
@@ -63,9 +62,6 @@
 #include <nsIFind.h>
 #include <dom/nsIDOMNSDocument.h>
 #include <dom/nsIDOMNSEvent.h>
-#include <docshell/nsIDocShell.h>
-#include <docshell/nsIDocShellTreeItem.h>
-#include <docshell/nsIDocShellTreeOwner.h>
 #include <nsIDOMNodeList.h>
 #include <nsIDOMWindow.h>
 #include <nsISelection.h>
@@ -299,12 +295,19 @@ static guint	     kz_moz_embed_get_last_modified     (KzEmbed      *kzembed);
 static void         kz_moz_embed_set_edit_mode         (KzEmbed      *kzembed);
 static void         kz_moz_embed_set_view_mode         (KzEmbed      *kzembed);
 #endif
-static void         kz_moz_embed_fine_scroll           (KzEmbed      *kzembed,
-							int           horiz, 
-							int vert);
+static void         kz_moz_embed_fine_scroll            (KzEmbed      *kzembed,
+							 int           horiz, 
+							 int           vert);
 static void	     kz_moz_embed_page_up		(KzEmbed      *kzembed);
 static void	     kz_moz_embed_page_down		(KzEmbed      *kzembed);
 
+static gboolean	     kz_moz_embed_get_allow_javascript	(KzEmbed      *kzembed);
+static void	     kz_moz_embed_set_allow_javascript	(KzEmbed      *kzembed,
+    							 gboolean      allow);
+static gboolean	     kz_moz_embed_get_allow_images	(KzEmbed      *kzembed);
+static void	     kz_moz_embed_set_allow_images	(KzEmbed      *kzembed,
+    							 gboolean      allow);
+
 static GtkMozEmbedClass *parent_class = NULL;
 
 static void
@@ -372,6 +375,10 @@ kz_moz_embed_iface_init (KzEmbedIFace *iface)
 	iface->fine_scroll            = kz_moz_embed_fine_scroll;
 	iface->page_up                = kz_moz_embed_page_up;
 	iface->page_down              = kz_moz_embed_page_down;
+	iface->get_allow_javascript   = kz_moz_embed_get_allow_javascript;
+	iface->set_allow_javascript   = kz_moz_embed_set_allow_javascript;
+	iface->get_allow_images       = kz_moz_embed_get_allow_images;
+	iface->set_allow_images       = kz_moz_embed_set_allow_images;
 #if 0
 	iface->set_edit_mode          = set_edit_mode;
 	iface->set_view_mode          = set_view_mode;
@@ -550,6 +557,7 @@ KZ_OBJECT_FINALIZE (kz_moz_embed, KzMozEmbed)
 static void
 kz_moz_embed_realize (GtkWidget *widget)
 {
+	gboolean java = TRUE;
 	if (GTK_WIDGET_CLASS(parent_class)->realize)
 		GTK_WIDGET_CLASS(parent_class)->realize(widget);
 
@@ -563,7 +571,12 @@ kz_moz_embed_realize (GtkWidget *widget)
 		{
 			g_error("KzMozEmbed: Faild to init KzMozWrapper!");
 		}
+		else
+		{
+		}
 	}
+	KZ_CONF_GET("Global", "use_javascript", java, BOOL);
+	kz_moz_embed_set_allow_javascript(KZ_EMBED(kzembed), java);
 }
 
 
@@ -1783,15 +1796,21 @@ START_SEARCH:
 	finder->SetMatchCase(FALSE);
 	PRBool did_find;
 	rv = finder->FindNext(&did_find);
-#if 0	
+
 	// highlight search word
-	if (NS_SUCCEEDED(rv))
+	
+	gboolean use_highlight = FALSE;
+	KZ_CONF_GET("Global", "use_highlight", use_highlight, BOOL);
+	if (use_highlight)
 	{
-		nsEmbedCString c_str;
-		NS_UTF16ToCString(str, NS_CSTRING_ENCODING_UTF8, c_str);
-		kz_moz_embed_highlight_word(kzembed, c_str.get());
+		if (NS_SUCCEEDED(rv))
+		{
+			nsEmbedCString c_str;
+			NS_UTF16ToCString(str, NS_CSTRING_ENCODING_UTF8, c_str);
+			kz_moz_embed_highlight_word(kzembed, c_str.get());
+		}
 	}
-#endif
+
 	return NS_SUCCEEDED(rv) && did_find ? TRUE : FALSE;
 }
 
@@ -3070,3 +3089,61 @@ kz_moz_embed_page_down (KzEmbed *kzembed)
 	wrapper->PageDown();
 }
 
+static gboolean
+kz_moz_embed_get_allow_javascript (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_MOZ_EMBED(kzembed), FALSE);
+
+	KzMozEmbed *mozembed = KZ_MOZ_EMBED(kzembed);
+	KzMozWrapper *wrapper = mozembed->priv->wrapper;
+
+	if (!wrapper) return FALSE;
+
+	PRBool allow;
+	wrapper->GetAllowJavascript(&allow);
+
+	return allow ? TRUE : FALSE;
+}
+
+static void
+kz_moz_embed_set_allow_javascript (KzEmbed *kzembed, gboolean allow)
+{
+	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
+
+	KzMozEmbed *mozembed = KZ_MOZ_EMBED(kzembed);
+	KzMozWrapper *wrapper = mozembed->priv->wrapper;
+
+	if (!wrapper) return;
+	
+	wrapper->SetAllowJavascript(allow);
+}
+
+static gboolean
+kz_moz_embed_get_allow_images (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_MOZ_EMBED(kzembed), FALSE);
+
+	KzMozEmbed *mozembed = KZ_MOZ_EMBED(kzembed);
+	KzMozWrapper *wrapper = mozembed->priv->wrapper;
+
+	if (!wrapper) return FALSE;
+
+	PRBool allow;
+	wrapper->GetAllowImages(&allow);
+
+	return allow ? TRUE : FALSE;
+}
+
+static void
+kz_moz_embed_set_allow_images (KzEmbed *kzembed, gboolean allow)
+{
+	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
+
+	KzMozEmbed *mozembed = KZ_MOZ_EMBED(kzembed);
+	KzMozWrapper *wrapper = mozembed->priv->wrapper;
+
+	if (!wrapper) return;
+	
+	wrapper->SetAllowImages(allow);
+}
+
