@@ -37,16 +37,12 @@ class KzMozEventListener : public nsIDOMEventListener
 	nsresult Init(KzMozEmbed *aOwner);
 
 	NS_DECL_ISUPPORTS
-
-	// nsIDOMEventListener
-
-	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+	NS_DECL_NSIDOMEVENTLISTENER
 
  private:
 	KzMozEmbed *mOwner;
 
-	nsresult HandleFaviconLink (nsIDOMNode *node);
-	nsresult HandleRSSLink     (nsIDOMNode *node);
+	nsresult HandleLink        (nsIDOMNode *node);
 };
 
 #endif /* __KZ_MOZ_EVENT_LISTENER_H__ */
