@@ -124,7 +124,7 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 	filePicker->SetDefaultString(defaultFile);
 #else
 	filePicker->Init(windowInternal,
-			 PromiseFlatString(title).get(), 
+			 title.get(), 
 			 nsIFilePicker::modeSave);
 	filePicker->SetDefaultString(aDefaultFile);
 #endif
