@@ -26,9 +26,13 @@
 
 #include <nsIWebProgressListener.h>
 #include <nsWeakReference.h>
-#include <nsIDownload.h>
 #include <nsIObserver.h>
 #include <nsIWebBrowserPersist.h>
+#ifdef HAVE_NSITRANSFER_H
+#include <nsITransfer.h>
+#else
+#include <nsIDownload.h>
+#endif
 
 #define KZ_DOWNLOAD_CID                \
 { /* d2a2f743-f126-4f1f-1234-d4e50490f112 */         \
@@ -40,9 +44,13 @@
 
 #define KZ_DOWNLOAD_CLASSNAME "Kazehakase's Download Progress Listener"
 
-class KzMozProgressListener : public nsIWebProgressListener,	
-                              public nsIDownload,
-                              public nsSupportsWeakReference
+class KzMozProgressListener : 
+#ifdef HAVE_NSITRANSFER_H
+  			      public nsITransfer	
+#else
+  			      public nsIWebProgressListener,	
+                              public nsIDownload
+#endif
 {
  public:
 	KzMozProgressListener();
@@ -50,11 +58,18 @@ class KzMozProgressListener : public nsIWebProgressListener,
 
 	NS_DECL_ISUPPORTS
 	NS_DECL_NSIWEBPROGRESSLISTENER
-	NS_DECL_NSIDOWNLOAD
-#if MOZILLA_SNAPSHOT > 14
 	NS_DECL_NSITRANSFER
+#ifndef HAVE_NSITRANSFER_H
+	NS_DECL_NSIDOWNLOAD
 #endif
 
+#ifdef HAVE_NSITRANSFER_H
+	nsresult GetMIMEInfo (nsIMIMEInfo **aMIMEInfo);
+	nsresult GetTargetFile (nsILocalFile **aFile);
+	nsresult GetSource(nsIURI * *aSource);
+	nsresult GetPercentComplete(PRInt32 *aPercentComplete);
+
+#endif
 	nsresult Cancel();
 
 	PRInt32 mPercentComplete;
