@@ -30,33 +30,36 @@
 #include "mozilla.h"
 #include "utils.h"
 #include "egg-pixbuf-thumbnail.h"
+#include "kz-mozutils.h"
+#include "MozillaPrivate.h"
 
 #include <nsCOMPtr.h>
+#include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIDOMDocument.h>
-#include <content/nsIDocumentViewer.h>
-#include <content/nsIContent.h>
+#include <nsIDocumentViewer.h>
 #include <nsIWebBrowser.h>
-#include <content/nsIDocument.h>
 #include <dom/nsIDOMNSDocument.h>
 #include <docshell/nsIDocShell.h>
 #include <nsIDOMWindow.h>
-#include <necko/nsNetUtil.h>
-#include <uconv/nsICharsetConverterManager.h>
 #include <nsISHistory.h>
 #include <nsIHistoryEntry.h>
 #include <nsISHEntry.h>
 #include <nsIWebNavigation.h>
 #include <nsIWebBrowserPrint.h>
 #include <nsIWebBrowserSetup.h>
-#include <nsIPrintOptions.h>
 #include <nsIPrintSettings.h>
 #include <nsIPrintSettingsService.h>
 #include <nsISHistoryInternal.h>
 #include <docshell/nsIDocShellTreeItem.h>
 #include <nsIDocShellTreeOwner.h>
 #include <nsTime.h>
-
 #include <nsCWebBrowser.h>
+#include <nsIDOM3Node.h>
+
 struct _KzMozThumbnailCreatorPriv
 {
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
@@ -229,44 +232,36 @@ net_stop_proccess (KzMozThumbnailCreator *creator)
 
 	//get the last modification time
 	nsCOMPtr<nsIDOMNSDocument> nsDoc = do_QueryInterface(domDoc);
-	nsAutoString value;
+	nsEmbedString value;
 	nsDoc->GetLastModified(value);
-	nsTime lm (NS_ConvertUCS2toUTF8(value).get(), PR_TRUE);
+	nsEmbedCString cValue;
+	NS_UTF16ToCString(value,
+			  NS_CSTRING_ENCODING_UTF8, cValue);
+	nsTime lm (cValue.get(), PR_TRUE);
 	GTime last_modified;
 	LL_DIV(last_modified,
 	       NS_STATIC_CAST(PRTime, lm), PR_USEC_PER_SEC);
 
-	nsCOMPtr<nsIURI> inURI;
-	nsCAutoString sURI;
+	nsCOMPtr<nsIDOM3Node> domnode = do_QueryInterface(domDoc);
+     	if(!domnode) return;
 
-	nsCOMPtr<nsIDocument> doc = do_QueryInterface(domDoc);
-	if(!doc) return; 
+	nsEmbedString spec;
+	domnode->GetBaseURI(spec);
 
-#if MOZILLA_SNAPSHOT > 12
-	nsIURI *uri;
-	uri = doc->GetDocumentURI();
-#else
-	nsIURI *uri;
-	uri = doc->GetDocumentURL();
-#endif
+	nsEmbedCString sURI;
+	NS_UTF16ToCString(spec,
+			  NS_CSTRING_ENCODING_UTF8, sURI);
 
-	rv =  uri->GetSpec(sURI);
-      	rv = NS_NewURI(getter_AddRefs(inURI), sURI);
-
-	if (sURI.Equals("about:blank"))
+	if (!g_ascii_strcasecmp(sURI.get(), "about:blank"))
 		return;
 
-	gchar *guri = ToNewCString(sURI);
-
-	if ((!last_modified || (thumbnail_get_last_modified(guri) < last_modified)))
+	if ((!last_modified || (thumbnail_get_last_modified(sURI.get()) < last_modified)))
 	{
 		SiteInfo *info = g_new0(SiteInfo, 1);
 		info->creator = creator;
-		info->uri = g_strdup(guri);
+		info->uri = g_strdup(sURI.get());
 		g_idle_add(idle_create_thumbnail, (gpointer)info);
 	}
-
-	g_free(guri);
 }
 
 
@@ -295,21 +290,12 @@ kz_moz_thumbnail_creator_create_thumbnail (KzMozThumbnailCreator *creator, const
 		creator->priv->is_creating = FALSE;
 		return;
 	}
-	nsCOMPtr<nsIPrintOptions> printService;
-	printService = do_GetService("@mozilla.org/gfx/printsettings-service;1");
-	if (!printService) 
+
+	if (!MozillaPrivate::CreatePrintSettings(getter_AddRefs(options)))
 	{
 		creator->priv->is_creating = FALSE;
 		return;
 	}
-
-//	nsCOMPtr<nsIPrintSettingsService> printSettingsService;
-//	printSettingsService = do_GetService("@mozilla.org/gfx/printsettings-service;1");
-//	if (!printSettingsService) return;
-	
-//	printSettingsService->GetNewPrintSettings(getter_AddRefs(options));
-
-	printService->CreatePrintSettings(getter_AddRefs(options));
 	
 	gchar *thumb_filename;
 	thumb_filename = egg_pixbuf_get_thumb_filename(uri,
@@ -325,16 +311,27 @@ kz_moz_thumbnail_creator_create_thumbnail (KzMozThumbnailCreator *creator, const
 	options->SetMarginLeft(0.0);
 	options->SetMarginBottom(0.0);
 	options->SetMarginRight(0.0);
-	options->SetPrinterName(NS_LITERAL_STRING("PostScript/default").get());
-	options->SetHeaderStrLeft(NS_LITERAL_STRING("").get());
-	options->SetHeaderStrCenter(NS_LITERAL_STRING("").get());
-	options->SetHeaderStrRight(NS_LITERAL_STRING("").get());
-	options->SetFooterStrLeft(NS_LITERAL_STRING("").get());
-	options->SetFooterStrCenter(NS_LITERAL_STRING("").get());
-	options->SetFooterStrRight(NS_LITERAL_STRING("").get());
+	nsEmbedString printer;
+	NS_CStringToUTF16(nsEmbedCString("PostScript/default"),
+			  NS_CSTRING_ENCODING_UTF8, printer);
+	options->SetPrinterName(printer.get());
+	nsEmbedString tmp;
+	NS_CStringToUTF16(nsEmbedCString(""), NS_CSTRING_ENCODING_UTF8, tmp);
+	options->SetHeaderStrLeft(tmp.get());
+	options->SetHeaderStrCenter(tmp.get());
+	options->SetHeaderStrRight(tmp.get());
+	options->SetFooterStrLeft(tmp.get());
+	options->SetFooterStrCenter(tmp.get());
+	options->SetFooterStrRight(tmp.get());
 	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
-	options->SetPaperName(NS_LITERAL_STRING("Letter").get());
-	options->SetToFileName(NS_ConvertUTF8toUCS2(ps_name).get());
+
+	NS_CStringToUTF16(nsEmbedCString("Letter"),
+			  NS_CSTRING_ENCODING_UTF8, tmp);
+	options->SetPaperName(tmp.get());
+	NS_CStringToUTF16(nsEmbedCString(ps_name),
+			  NS_CSTRING_ENCODING_UTF8, tmp);
+	
+	options->SetToFileName(tmp.get());
 	options->SetPrintToFile(PR_TRUE);	
 	options->SetPrintInColor(PR_TRUE);
 	options->SetOrientation(nsIPrintSettings::kLandscapeOrientation);
@@ -353,12 +350,15 @@ kz_moz_thumbnail_creator_create_thumbnail (KzMozThumbnailCreator *creator, const
 	while (printing)
 	{
 		print->GetDoingPrintPreview(&printing);
+		if (!printing)
+			break;
+
 		while (gtk_events_pending())
 			gtk_main_iteration();
 	}
-
 	KzMozThumbnailProgressListener *aProgress = new KzMozThumbnailProgressListener(ps_name, creator);
 	rv = print->Print(options, aProgress);
+
 	g_free(ps_name);
 }
 
