@@ -23,16 +23,20 @@
 
 #include <sys/utsname.h>
 #include <gtkmozembed.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsBuildID.h>
 #include <nsCOMPtr.h>
 #include <nsIPrefService.h>
-#include <uconv/nsICharsetConverterManager.h>
-#if MOZILLA_SNAPSHOT < 10
-#	include <uconv/nsICharsetConverterManager2.h>
-#endif
 #include <nsISupportsPrimitives.h>
-#include <gfx/nsIFontList.h>
-#include <necko/nsNetUtil.h>
+#include <nsIServiceManager.h>
+#if 0
+#include <nsIFontEnumerator.h>
+#endif
+#include <nsISimpleEnumerator.h>
+#include <nsIFontList.h>
+#include <nsMemory.h>
 
 #include "kazehakase.h"
 #include "kz-profile.h"
@@ -42,19 +46,16 @@
 extern "C" gboolean
 mozilla_prefs_init (void)
 {
-	const char *home_path;
-	char full_path[256];
+	gchar *full_path;
 
-     	home_path = g_get_home_dir();
-	if (!home_path) {
-		g_error("Failed to get HOME");
-		return FALSE;
-	}
-
-	g_snprintf(full_path, G_N_ELEMENTS(full_path),
-		   "%s/%s", home_path, ".kazehakase/mozilla");
+	full_path = g_build_filename(g_get_home_dir(), 
+		   		     "."PACKAGE,
+				     "mozilla",
+				     NULL);
 	gtk_moz_embed_set_profile_path(full_path, "kazehakase");
 
+	g_free(full_path);
+
 	return TRUE;
 }
 
@@ -289,6 +290,7 @@ gboolean
 mozilla_prefs_get_font_list (const char *lang_group,
 			     const char *font_type,
 			     GList **font_list,
+			     GList **all_font_list,
 			     char **default_font)
 {
 	nsresult rv;
@@ -298,8 +300,12 @@ mozilla_prefs_get_font_list (const char *lang_group,
 	if(NS_FAILED(rv)) return FALSE;
 
 	nsCOMPtr<nsISimpleEnumerator> fontEnum;
-	mozFontList->AvailableFonts(NS_ConvertUTF8toUCS2(lang_group).get(),
-				    NS_ConvertUTF8toUCS2(font_type).get(),
+	nsEmbedString lang, font;
+	NS_CStringToUTF16(nsEmbedCString(lang_group),
+			  NS_CSTRING_ENCODING_UTF8, lang);
+	NS_CStringToUTF16(nsEmbedCString(font_type),
+			  NS_CSTRING_ENCODING_UTF8, font);
+	mozFontList->AvailableFonts(lang.get(), font.get(),
 				    getter_AddRefs(fontEnum));
 	if(NS_FAILED(rv)) return FALSE;
 
@@ -316,11 +322,13 @@ mozilla_prefs_get_font_list (const char *lang_group,
 			fontEnum->GetNext(getter_AddRefs(fontName));
 			if(NS_FAILED(rv)) return FALSE;
 
-			nsString fontString;
+			nsEmbedString fontString;
 			fontName->GetData(fontString);
 
-			char *gFontString;
-			gFontString = g_strdup(NS_ConvertUCS2toUTF8(fontString).get());
+			nsEmbedCString tmp;
+			NS_UTF16ToCString(fontString,
+					  NS_CSTRING_ENCODING_UTF8, tmp);
+			char *gFontString = g_strdup(tmp.get());
 			list = g_list_prepend(list, gFontString);
 		}
 		*font_list = g_list_reverse(list);
@@ -347,6 +355,73 @@ mozilla_prefs_get_font_list (const char *lang_group,
 		nsMemory::Free(value);
 	}
 
+#if 0
+	nsresult rv;
+	PRUint32 count;
+	PRUnichar **fontArray;
+
+	nsCOMPtr<nsIFontEnumerator> mozFontEnumerator;
+	mozFontEnumerator = do_CreateInstance("@mozilla.org/gfx/fontenumerator;1");
+	NS_ENSURE_TRUE (mozFontEnumerator, FALSE);
+
+	// get the language proper fonts
+	rv = mozFontEnumerator->EnumerateFonts(lang_group, font_type,
+					       &count, &fontArray);
+	NS_ENSURE_SUCCESS (rv, FALSE);
+
+	if (font_list)
+	{
+		GList *list = NULL;
+		for (PRUint32 i = 0; i < count; i++)
+		{
+			char *gFontString;
+
+			nsEmbedCString tmp;
+			NS_UTF16ToCString(nsEmbedString(fontArray[i]),
+					  NS_CSTRING_ENCODING_UTF8, tmp);
+			gFontString = g_strdup(tmp.get());
+			list = g_list_prepend(list, gFontString);
+			nsMemory::Free (fontArray[i]);
+		}
+		*font_list = g_list_reverse(list);
+	}
+	nsMemory::Free (fontArray);
+
+	// get all fonts
+	rv = mozFontEnumerator->EnumerateAllFonts(&count, &fontArray);
+	NS_ENSURE_SUCCESS (rv, FALSE);
+
+	if (font_list)
+	{
+		GList *list = NULL;
+		for (PRUint32 i = 0; i < count; i++)
+		{
+			char *gFontString;
+
+			nsEmbedCString tmp;
+			NS_UTF16ToCString(nsEmbedString(fontArray[i]),
+					  NS_CSTRING_ENCODING_UTF8, tmp);
+			gFontString = g_strdup(tmp.get());
+			list = g_list_prepend(list, gFontString);
+			nsMemory::Free (fontArray[i]);
+		}
+		*all_font_list = g_list_reverse(list);
+	}
+	nsMemory::Free (fontArray);
+
+	if (default_font != NULL)
+	{
+		PRUnichar *value;
+		rv = mozFontEnumerator->GetDefaultFont(lang_group,
+						       font_type,
+						       &value);
+		nsEmbedCString tmp;
+		NS_UTF16ToCString(nsEmbedString(value),
+				  NS_CSTRING_ENCODING_UTF8, tmp);
+		*default_font = g_strdup(tmp.get());
+		nsMemory::Free(value);
+	}
+#endif
 	return TRUE;
 }
 
@@ -419,3 +494,4 @@ mozilla_prefs_set_proxy (KzProxyItem *item)
 	if (no_proxies_on)
 		g_free(no_proxies_on);
 }
+
