@@ -28,8 +28,11 @@
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
 #include <nsIPasswordManager.h>
-#include <nsIPassword.h>
 #include <nsCPasswordManager.h>
+#ifdef HAVE_NSIPASSWORD_H
+#include <nsIPassword.h>
+#endif
+#include <nsIIDNService.h>
 
 #include "mozilla.h"
 #include "mozilla-prefs.h"
@@ -59,7 +62,11 @@ static const nsModuleComponentInfo sAppComps[] = {
 	{
 		KZ_DOWNLOAD_CLASSNAME,
 		KZ_DOWNLOAD_CID,
+#ifdef HAVE_NSITRANSFER_H
+		NS_TRANSFER_CONTRACTID,
+#else
 		NS_DOWNLOAD_CONTRACTID,
+#endif
 		KzMozProgressListenerConstructor
 	},
 	{
@@ -157,7 +164,7 @@ new_window_orphan_cb (GtkMozEmbedSingle *embed, GtkMozEmbed **retval,
 	GtkMozEmbed *newBrowser = GTK_MOZ_EMBED(gtk_moz_embed_new());
 
 	gtk_container_add(GTK_CONTAINER(newWindow), GTK_WIDGET(newBrowser));
-	g_signal_connect(G_OBJECT(newBrowser),"destroy_browser",
+	g_signal_connect(newBrowser,"destroy_browser",
 			 G_CALLBACK(destroy_browser_cb),newWindow);
 	*retval = GTK_MOZ_EMBED(newBrowser);
 }
@@ -206,6 +213,8 @@ mozilla_init (void)
 
 	mozilla_prefs_init();
 
+	gtk_moz_embed_set_comp_path(MOZILLA_HOME);
+
 	gtk_moz_embed_push_startup();
 
 	mozilla_prefs_set();
@@ -220,10 +229,10 @@ mozilla_init (void)
 		return;
 	}
 
-	g_signal_connect(G_OBJECT(single), "new_window_orphan",
+	g_signal_connect(single, "new_window_orphan",
 			 G_CALLBACK(new_window_orphan_cb), NULL);
 
-	g_signal_connect(G_OBJECT(kz_global_profile), "changed::Global",
+	g_signal_connect(kz_global_profile, "changed::Global",
 			 G_CALLBACK(cb_profile_changed), NULL);
 
 
@@ -261,13 +270,17 @@ mozilla_get_passwords (GList **passwords)
 
                 PasswordInfo *p = g_new0 (PasswordInfo, 1);
 
-                nsCAutoString transfer;
+                nsEmbedCString transfer;
                 nsPassword->GetHost (transfer);
                 p->host = g_strdup (transfer.get());
 
-		nsAutoString unicodeName;
+		nsEmbedString unicodeName;
 		nsPassword->GetUser (unicodeName);
-		p->username = g_strdup(NS_ConvertUCS2toUTF8(unicodeName).get());
+
+		nsEmbedCString userName;
+		NS_UTF16ToCString(unicodeName,
+				  NS_CSTRING_ENCODING_UTF8, userName);
+		p->username = g_strdup(userName.get());
 
 		*passwords = g_list_prepend (*passwords, p);
         }       
@@ -285,11 +298,22 @@ mozilla_remove_passwords (GList *passwords)
         nsCOMPtr<nsIPasswordManager> passwordManager =
                         do_GetService(NS_PASSWORDMANAGER_CONTRACTID);
 
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+
+
         for (GList *l = passwords; l != NULL; l = l->next)
         {
                 PasswordInfo *p = (PasswordInfo *)l->data;
-		result = passwordManager->RemoveUser (nsDependentCString(p->host),
-						      NS_ConvertUTF8toUCS2(nsDependentCString(p->username)));
+		nsresult rv;
+		nsEmbedCString host;
+		rv = idnService->ConvertUTF8toACE (nsEmbedCString(p->host), host);
+		
+		nsEmbedString userName;
+		NS_CStringToUTF16(nsEmbedCString(p->username), 
+				  NS_CSTRING_ENCODING_UTF8, userName);
+		
+		result = passwordManager->RemoveUser(host, userName);
                 if (NS_FAILED(result)) return FALSE;
         }
 	
