@@ -28,6 +28,9 @@ G_BEGIN_DECLS
 void      mozilla_init                 (void);
 void      mozilla_exit                 (void);
 
+gboolean  mozilla_get_passwords        (GList **passwords);
+gboolean  mozilla_remove_passwords     (GList *passwords);
+
 G_END_DECLS
 
 #endif /* __MOZILLA_H__ */
