@@ -733,6 +733,27 @@ kz_http_start (KzIO *io)
 		   so connect without proxy */
 		goto NO_PROXY;
 	}
+	
+	/* check the need of the poxy */
+	if (item->no_proxies_on)
+	{
+		gchar **no_proxies;
+		gint i = 0;
+		no_proxies = g_strsplit_set(item->no_proxies_on, ", ", -1);
+
+		if (!no_proxies)	
+			goto NO_PROXY;
+		while (no_proxies[i])
+		{
+			if (g_str_has_suffix(http->priv->hostname, no_proxies[i]))
+			{
+				g_strfreev(no_proxies);
+				goto NO_PROXY;
+			}
+			i++;
+		}
+		g_strfreev(no_proxies);
+	}
 
 	/* There is a valid proxy setting, so connect with this proxy*/
 	http->priv->use_proxy = TRUE;
@@ -751,7 +772,6 @@ NO_PROXY:
 }
 
 
-
 static void
 kz_http_error (KzHTTP *http)
 {
