@@ -144,7 +144,7 @@ prefs_history_create (void)
 		gtk_check_button_new_with_label(_("Store history cache for search"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
 				     store_cache);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_store_cache_toggled), prefsui);
 	frame = gtk_frame_new("");
 	gtk_frame_set_label_widget(GTK_FRAME(frame), check);
@@ -175,7 +175,7 @@ prefs_history_create (void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), limit);
 	gtk_widget_set_sensitive(check, store_cache);
 	gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_limit_days_toggled), prefsui);
 	gtk_widget_show(check);
 
@@ -185,7 +185,7 @@ prefs_history_create (void)
 	gtk_adjustment_set_value(adj, limit_days);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);
 	gtk_widget_set_sensitive(spin, limit && store_cache);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -207,7 +207,7 @@ prefs_history_create (void)
 		= gtk_button_new_with_label (_("start"));
 	gtk_widget_set_sensitive(button, store_cache);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 4);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_optimize_button_clicked), prefsui);
 	gtk_widget_show(button);
 
@@ -240,7 +240,7 @@ prefs_history_create (void)
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
 	gtk_adjustment_set_value(adj, max_results);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -259,7 +259,7 @@ prefs_history_create (void)
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
 	gtk_adjustment_set_value(adj, num_summary);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
