@@ -488,7 +488,7 @@ prefs_proxy_create (void)
 	gtk_frame_set_label_widget(GTK_FRAME(frame), check);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefsui->use_proxy),
 				     use_proxy);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_use_proxy_toggled), prefsui);
 	gtk_widget_show(check);
 
@@ -530,7 +530,7 @@ prefs_proxy_create (void)
 
 	/* Selected column */
 	cell = gtk_cell_renderer_toggle_new();
-	g_signal_connect(G_OBJECT(cell), "toggled",
+	g_signal_connect(cell, "toggled",
 			 G_CALLBACK(cb_selected_col_toggled), prefsui);
 	gtk_cell_renderer_toggle_set_radio
 		(GTK_CELL_RENDERER_TOGGLE(cell), TRUE);
@@ -544,7 +544,7 @@ prefs_proxy_create (void)
 
 	/* Name column */
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_name_col_edited), prefsui);
 	column = gtk_tree_view_column_new_with_attributes
 			(_("Proxy Name"), cell,
@@ -618,7 +618,7 @@ prefs_proxy_create (void)
 	gtk_container_add(GTK_CONTAINER(button), arrow);
 	gtk_widget_show(arrow);
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 5);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_up_button), prefsui);
 	gtk_widget_show(button);
 
@@ -628,7 +628,7 @@ prefs_proxy_create (void)
 	gtk_container_add(GTK_CONTAINER(button), arrow);
 	gtk_widget_show(arrow);
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 5);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_down_button), prefsui);
 	gtk_widget_show(button);
 
@@ -657,7 +657,7 @@ prefs_proxy_create (void)
 	prefsui->name = entry = gtk_entry_new();
 	gtk_widget_set_size_request(entry, 100, -1);
         gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_name_changed), prefsui);
 	gtk_widget_show(entry);
 
@@ -682,13 +682,13 @@ prefs_proxy_create (void)
 	prefsui->http_host = entry = gtk_entry_new();
 	gtk_widget_set_size_request(entry, 250, -1);
 	gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 3, 4);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_http_host_changed), prefsui);
 	gtk_widget_show(entry);
 
 	prefsui->http_port = spin = gtk_spin_button_new_with_range(0, 65535, 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), spin, 2, 3, 3, 4);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_http_port_value_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -700,13 +700,13 @@ prefs_proxy_create (void)
 	prefsui->https_host = entry = gtk_entry_new();
 	gtk_widget_set_size_request(entry, 250, -1);
 	gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 4, 5);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_https_host_changed), prefsui);
 	gtk_widget_show(entry);
 
 	prefsui->https_port = spin = gtk_spin_button_new_with_range(0, 65535, 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), spin, 2, 3, 4, 5);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_https_port_value_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -718,13 +718,13 @@ prefs_proxy_create (void)
 	prefsui->ftp_host = entry = gtk_entry_new();
 	gtk_widget_set_size_request(entry, 250, -1);
 	gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 5, 6);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_ftp_host_changed), prefsui);
 	gtk_widget_show(entry);
 
 	prefsui->ftp_port = spin = gtk_spin_button_new_with_range(0, 65535, 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), spin, 2, 3, 5, 6);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_ftp_port_value_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -732,7 +732,7 @@ prefs_proxy_create (void)
 	prefsui->use_same_proxy = check = gtk_check_button_new_with_label
 		(_("Use http proxy for all other protocols"));
 	gtk_table_attach_defaults(GTK_TABLE(table), check, 0, 3, 6, 7);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_use_same_proxy_toggled), prefsui);
 	gtk_widget_show(check);
 
@@ -751,7 +751,7 @@ prefs_proxy_create (void)
 	prefsui->no_proxies_on = entry = gtk_entry_new();
 	gtk_widget_set_size_request(entry, 200, -1);
         gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 5);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_no_proxies_on_changed), prefsui);
 	gtk_widget_show(entry);
 
@@ -766,7 +766,7 @@ prefs_proxy_create (void)
 	button = gtk_button_new_from_stock(GTK_STOCK_NEW);
 	prefsui->new = button;
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_new_button), prefsui);
 	gtk_widget_show(button);
 
@@ -774,7 +774,7 @@ prefs_proxy_create (void)
 	button = gtk_button_new_from_stock(GTK_STOCK_ADD);
 	prefsui->add = button;
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_add_button), prefsui);
 	gtk_widget_show(button);
 
@@ -782,11 +782,11 @@ prefs_proxy_create (void)
 	button = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
 	prefsui->remove = button;
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_remove_button), prefsui);
 	gtk_widget_show(button);
 
-        g_signal_connect(G_OBJECT(tree_view), "cursor-changed",
+        g_signal_connect(tree_view, "cursor-changed",
                          G_CALLBACK(cb_cursor_changed), prefsui);
 
 	prefs_proxy_set_values(prefsui);
