@@ -56,6 +56,7 @@ typedef struct _KzPrefsTab
 	GtkComboBox   *close_menu;
    	GtkWidget     *focus_new_tab;
    	GtkWidget     *focus_loc_ent;
+   	GtkWidget     *focus_mid_click_link;
 	GtkComboBox   *new_tab_position_menu;
 	GdkColor       color[KZ_TAB_LABEL_N_STATE];
 	gboolean       changed;
@@ -176,7 +177,7 @@ prefs_tab_create (void)
 	prefsui->fix_width_check = check;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), fix);
 	gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_fix_width_toggled), prefsui);
 	gtk_widget_show(check);
 
@@ -186,7 +187,7 @@ prefs_tab_create (void)
 	gtk_adjustment_set_value(adj, width);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);
 	gtk_widget_set_sensitive(spin, fix);
-	g_signal_connect(G_OBJECT(spin), "value-changed",
+	g_signal_connect(spin, "value-changed",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -211,7 +212,7 @@ prefs_tab_create (void)
 	show = TRUE;
 	KZ_CONF_GET("Tab", "show_favicon", show, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 
@@ -221,7 +222,7 @@ prefs_tab_create (void)
 	show = TRUE;
 	KZ_CONF_GET("Tab", "show_close_button", show, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), show);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 
@@ -245,7 +246,7 @@ prefs_tab_create (void)
 	circulation = FALSE;
 	KZ_CONF_GET("Tab", "wheel_circulation", circulation, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), circulation);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 
@@ -282,7 +283,7 @@ prefs_tab_create (void)
 	GTKUTIL_SET_DEFAULT_HISTORY(option_menu, str,
 				    page_to_return, n_page_to_return, code);
 	g_free(str);
-	g_signal_connect (G_OBJECT(option_menu), "changed",
+	g_signal_connect (option_menu, "changed",
 			  G_CALLBACK (cb_changed), prefsui);
 
 	/*
@@ -305,7 +306,17 @@ prefs_tab_create (void)
 	focus = FALSE;
 	KZ_CONF_GET("Tab", "focus_open_new", focus, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), focus);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
+			 G_CALLBACK(cb_changed), prefsui);
+	gtk_widget_show(check);
+
+	check = gtk_check_button_new_with_mnemonic(_("Move focus to new tab on middle-clicking link"));
+	prefsui->focus_mid_click_link = check;
+	gtk_box_pack_start(GTK_BOX(vbox), check, FALSE, FALSE, 2);
+	focus = FALSE;
+	KZ_CONF_GET("Tab", "focus_mid_click_link", focus, BOOL);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), focus);
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 
@@ -315,7 +326,7 @@ prefs_tab_create (void)
 	key_focus = FALSE;
 	KZ_CONF_GET("Tab", "focus_loc_ent_new", key_focus, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), key_focus);
-	g_signal_connect(G_OBJECT(check), "toggled",
+	g_signal_connect(check, "toggled",
 			 G_CALLBACK(cb_changed), prefsui);
 	gtk_widget_show(check);
 	
@@ -346,7 +357,7 @@ prefs_tab_create (void)
 				    new_tab_position, 
 				    n_new_tab_position, code);
 	g_free(str);
-	g_signal_connect (G_OBJECT(option_menu), "changed",
+	g_signal_connect (option_menu, "changed",
 			  G_CALLBACK (cb_changed), prefsui);
 
 	/*
@@ -390,10 +401,10 @@ prefs_tab_create (void)
 	gtk_color_button_set_use_alpha(GTK_COLOR_BUTTON(cbutton) , FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), label , FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), cbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_tab_color_selection), 
 			  &prefsui->color[KZ_TAB_LABEL_STATE_NORMAL]);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
@@ -416,10 +427,10 @@ prefs_tab_create (void)
 	gtk_color_button_set_use_alpha(GTK_COLOR_BUTTON(cbutton) , FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), label , FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), cbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_tab_color_selection),
 			  &prefsui->color[KZ_TAB_LABEL_STATE_LOADING]);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
@@ -442,10 +453,10 @@ prefs_tab_create (void)
 	gtk_color_button_set_use_alpha(GTK_COLOR_BUTTON(cbutton) , FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), label , FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), cbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_tab_color_selection),
 			  &prefsui->color[KZ_TAB_LABEL_STATE_LOADED]);
-	g_signal_connect (G_OBJECT(cbutton), "color-set",
+	g_signal_connect (cbutton, "color-set",
 			  G_CALLBACK (cb_changed), prefsui);
 	gtk_widget_show(label);
 	gtk_widget_show(cbutton);
@@ -473,7 +484,7 @@ prefs_tab_response (GtkWidget *widget, gint response)
 		gint width;
 		gboolean fix_width;
 		gboolean show_button, show_favicon;
-		gboolean focus_new_tab, focus_loc_ent;
+		gboolean focus_new_tab, focus_loc_ent, focus_mid_click_link;
 		gboolean circulation;
 		
 		if (!prefsui->changed)
@@ -509,6 +520,10 @@ prefs_tab_response (GtkWidget *widget, gint response)
 				(GTK_TOGGLE_BUTTON(prefsui->focus_new_tab));
 		KZ_CONF_SET("Tab", "focus_open_new", focus_new_tab, BOOL);
 
+		focus_mid_click_link = gtk_toggle_button_get_active
+				(GTK_TOGGLE_BUTTON(prefsui->focus_mid_click_link));
+		KZ_CONF_SET("Tab", "focus_mid_click_link", focus_mid_click_link, BOOL);
+
 		focus_loc_ent = gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON(prefsui->focus_loc_ent));
 		KZ_CONF_SET("Tab", "focus_loc_ent_new", focus_loc_ent, BOOL);
