@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-sidebar.c,v 1.6 2004/11/22 01:08:41 ikezoe Exp $
+ *  $Id: kz-bookmarks-sidebar.c,v 1.7 2005/02/13 13:20:37 ikezoe Exp $
  */
 
 #include "kz-bookmarks-sidebar.h"
@@ -123,7 +123,7 @@ kz_bookmarks_sidebar_init (KzBookmarksSidebar *sidebar)
 					  KZ_BOOKMARK(kz_bookmarks),
 					  TRUE, FALSE, FALSE, FALSE);
 	gtk_container_add(GTK_CONTAINER(scrwin), view);
-	g_signal_connect(G_OBJECT(view), "button-press-event",
+	g_signal_connect(view, "button-press-event",
 			 G_CALLBACK(cb_button_press),
 			 sidebar);
 	gtk_widget_show(view);
