@@ -27,6 +27,7 @@
 G_BEGIN_DECLS
 
 void     make_dir                    (const gchar *dirname);
+void     make_thumbnails_dir         (void);
 gboolean key_seems_sequential        (const gchar *key,
 				      const gchar *prefix);
 gchar   *remove_tag                  (const gchar *string, gsize len);
@@ -41,13 +42,27 @@ gchar   *create_profile_key_from_uri (const gchar *string);
 
 gchar   *url_encode                  (const gchar *utf8src);
 gchar   *url_decode                  (const gchar *src);
+gchar   *ensure_encode_string        (const gchar *text, 
+				      const gchar *encode,
+				      gboolean urlencode);
+
+GTime   thumbnail_get_last_modified  (const gchar *uri);
+GTime   history_get_last_modified    (const gchar *uri);
 
 gchar   *complement_scheme           (const gchar *url);
 
 gchar   *xml_get_content	     (const gchar *buffer);
 gchar   *xml_get_attr		     (const gchar *buffer, const gchar *attr_name);
 
-void     purge_history_file	     (const gchar *path, time_t limit_seconds);
+GSList  *purge_history_file	     (const gchar *path,
+				      time_t limit_seconds);
+void	 convert_image		     (const gchar *ps_file,
+				      const gchar *png_file);
+gboolean str_isdigit 		     (const gchar *str);
+
+GSList  *find_file                   (const gchar *path,
+				      const gchar *fname,
+				      gint maxdepth);
 
 G_END_DECLS
 
