@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 3S30, Boston, MA 02111-1307, USA.
  *
- * $Id: kz-dlist.c,v 1.3 2004/09/30 00:06:08 ikezoe Exp $
+ * $Id: kz-dlist.c,v 1.5 2005/02/13 13:20:37 ikezoe Exp $
  */
 
 #include "kz-dlist.h"
@@ -260,16 +260,16 @@ kz_dlist_init (KzDList *dlist)
 	gtk_widget_set_size_request(dlist->up_button,   20, 20);
 	gtk_widget_set_size_request(dlist->down_button, 20, 20);
 
-	g_signal_connect(G_OBJECT(dlist->add_button), "clicked",
+	g_signal_connect(dlist->add_button, "clicked",
 			 G_CALLBACK(cb_add_button_pressed),
 			 dlist);
-	g_signal_connect(G_OBJECT(dlist->del_button), "clicked",
+	g_signal_connect(dlist->del_button, "clicked",
 			 G_CALLBACK(cb_del_button_pressed),
 			 dlist);
-	g_signal_connect(G_OBJECT(dlist->up_button), "clicked",
+	g_signal_connect(dlist->up_button, "clicked",
 			 G_CALLBACK(cb_up_button_pressed),
 			 dlist);
-	g_signal_connect(G_OBJECT(dlist->down_button), "clicked",
+	g_signal_connect(dlist->down_button, "clicked",
 			 G_CALLBACK(cb_down_button_pressed),
 			 dlist);
 
@@ -461,7 +461,7 @@ kz_dlist_column_add (KzDList *dlist, gint idx)
 	g_free (label);
 	g_free (id);
 
-	g_signal_emit_by_name(G_OBJECT(treeview1), "cursor-changed");
+	g_signal_emit_by_name(treeview1, "cursor-changed");
 
 	kz_dlist_available_list_updated(dlist);
 	kz_dlist_enabled_list_updated(dlist);
@@ -551,7 +551,7 @@ kz_dlist_column_del (KzDList *dlist, gint idx)
 	g_free(label);
 	g_free(id);
 
-	g_signal_emit_by_name(G_OBJECT(treeview2), "cursor-changed");
+	g_signal_emit_by_name(treeview2, "cursor-changed");
 
 	kz_dlist_available_list_updated(dlist);
 	kz_dlist_enabled_list_updated(dlist);
@@ -816,7 +816,7 @@ kz_dlist_available_list_updated (KzDList *dlist)
 {
 	g_return_if_fail(KZ_IS_DLIST(dlist));
 
-	g_signal_emit(GTK_OBJECT(dlist),
+	g_signal_emit(dlist,
 		      kz_dlist_signals[AVAILABLE_LIST_UPDATED_SIGNAL], 0);
 
 	kz_dlist_set_sensitive(dlist);
@@ -828,7 +828,7 @@ kz_dlist_enabled_list_updated (KzDList *dlist)
 {
 	g_return_if_fail(KZ_IS_DLIST(dlist));
 
-	g_signal_emit(GTK_OBJECT(dlist),
+	g_signal_emit(dlist,
 		      kz_dlist_signals[ENABLED_LIST_UPDATED_SIGNAL], 0);
 
 	kz_dlist_set_sensitive(dlist);
@@ -915,13 +915,13 @@ kz_dlist_create_list_widget (KzDList *dlist, gboolean reorderble)
 	if (reorderble)
 		gtk_tree_view_set_reorderable(GTK_TREE_VIEW(clist), TRUE);
 
-	g_signal_connect(G_OBJECT(store), "row_changed",
+	g_signal_connect(store, "row_changed",
 			 G_CALLBACK(cb_row_changed),
 			 dlist);
-	g_signal_connect(G_OBJECT(store), "row_deleted",
+	g_signal_connect(store, "row_deleted",
 			 G_CALLBACK(cb_row_deleted),
 			 dlist);
-	g_signal_connect(G_OBJECT(clist),"cursor_changed",
+	g_signal_connect(clist,"cursor_changed",
 			 G_CALLBACK(cb_cursor_changed),
 			 dlist);
 
