@@ -101,8 +101,6 @@ kz_paned_class_init (KzPanedClass *klass)
 static void
 kz_paned_init (KzPaned *kzpaned)
 {
-	g_return_if_fail (KZ_IS_PANED (kzpaned));
-
 	KZ_PANED_SET_HORIZONTAL(kzpaned);	
 	kzpaned->position  = GTK_POS_LEFT;
 }
@@ -165,7 +163,7 @@ kz_paned_set_position(KzPaned *kzpaned, GtkPositionType position)
 	}	
 	gtk_widget_queue_resize(GTK_WIDGET(kzpaned));
 
-	g_signal_emit(G_OBJECT(kzpaned),
+	g_signal_emit(kzpaned,
 		      kz_paned_signals[CHANGED_POSITION],
 		      0,
 		      position);
